4ulldrl3u3ruuruuldrdl3u5lddrud3lulldlluluullulldl5drruld6rdurrdllu5ldd3lddlddrd5ruuldu3rdrrurrdrddrrdrrur4ulu7luruulldrurdldd6ruu3r5u4ldd3lulld3l3ullulldl4dldrrl5ururr3dllrr3ullddl3drd6r5lull3uruurrdrr3d3r3u4l4rddrrdrru3l4ru4r5d3lddll4u4d4luulu5ldd3lddlddrd4r4luuluruu3r3ull3uruurrdluld4r3d3rulldlu8ruuldrdlrdl5d4luururrlldldd4r3u3drrd3ru4lruurdurrdlluldrr6dldll3urrll3drruur3uddl3dllull3u3l3d4rluulluldllulld6rurd8ld4l5urrururr4d4ulldd3lurrdru3l6d4rdrulurlur5u3rdrdd3l3ruulu3l3d4ruuru4l3r3dru
