#pragma once

#include "common/SoundType.h"

namespace caveexpress {

namespace SoundTypes {
extern SoundType SOUND_WATER_IMPACT;
extern SoundType SOUND_PLAYER_SPAWN;
extern SoundType SOUND_PLAYER_CRASH_HITPOINTS;
extern SoundType SOUND_PLAYER_CRASH_NPC_FLYING;
extern SoundType SOUND_PLAYER_CRASH_NPC_WALKING;
extern SoundType SOUND_PLAYER_CRASH_NPC_FISH;
extern SoundType SOUND_PLAYER_PAIN1;
extern SoundType SOUND_PLAYER_PAIN2;
extern SoundType SOUND_PLAYER_PAIN3;
extern SoundType SOUND_PLAYER_PAIN;
extern SoundType SOUND_NPC_FLYING_SPAWNED;
extern SoundType SOUND_PACKAGE_COLLIDE1;
extern SoundType SOUND_PACKAGE_COLLIDE2;
extern SoundType SOUND_PACKAGE_COLLIDE3;
extern SoundType SOUND_PACKAGE_COLLIDE4;
extern SoundType SOUND_PACKAGE_COLLIDE5;
extern SoundType SOUND_PACKAGE_COLLIDE;
extern SoundType SOUND_STONE_COLLIDE;
extern SoundType SOUND_FRUIT_SPAWN;
extern SoundType SOUND_FRUIT_COLLECTED;
extern SoundType SOUND_PLAYER_LAND;
extern SoundType SOUND_PLAYER_LAND1;
extern SoundType SOUND_PLAYER_LAND2;
extern SoundType SOUND_PLAYER_LAND3;
extern SoundType SOUND_WATER_LEAVE;
extern SoundType SOUND_WATER_RISING;
extern SoundType SOUND_MUSIC_WIN;
extern SoundType SOUND_AMBIENT_CAVE;
extern SoundType SOUND_AMBIENT_CAVE1;
extern SoundType SOUND_AMBIENT_CAVE2;
extern SoundType SOUND_AMBIENT_WATERFALL;
extern SoundType SOUND_NPC_CAVE_WATER_RESCUE;
extern SoundType SOUND_NPC_CAVE_BOARD;
}

}
