u5ldurrud10rdrr3u6ldurruudd6rll3dllurdr5duurr10ldduu4ldduullddrruu4ldduu4lrr6ull6rddll3du7r3ldulludlluurrlldllurrud4l4u3dllurldd4r4ulldduulluu2(rrdd)rruullruurdull3durrddlldd3luu3r4dll4d3ulldrluu3rlddrruu4dlluuddllddrruu4rlddluruldd2(rruu)lldurrddlluu4rddllrddl3udrruu8rdduu6lddlluullu5drr3udrr2(uull)4urruuddlluull4rluuldurrddlldd4ruulldurrddll3du3rdd3lrrurul4ruulluu3dulluurrluuldurrddll5drdldu4ruulluurruulldu3ruuldrdlddll3durr2(ddll)ddrrudlddludrruulluu4rddlludrruulluu4rddlludrruulluurrddlldd5rlddrruudd4ludllrddrudll4u4rddlluull3udrruullud4rddlld3(urr)3ud4luullddll4urr3durrddlldu4ruurr4lruurdull3durrddllddr3lddrruruluu4ruullrruurrddll4dlludrrurrulrddlluull4drruulrdd4lddll4rddlddluruludrruull4d2(rruu)lldurrddllrrddrruull4udrrdluldrruu4luurrddllururruu3ldd5ull6drrd3rdd3luu
