3l3dr3drdrr3urur3u4rd3lulddu7rurrd8luldrdlldl4dllurdr3uddllddrdr4u4d6r5u3ruur5drrdldl5urrdlu3l3drruuruuluu7luldl3dldd4ld3rdr3u4drrudrruu3ldluu3d6r4ururruuru7ldlruuldldduurrdluldu8rddrrdl4drruldl3ul3uru7luldrdlu7rddrrdldl3uru6luld7r6dlluulurdr3uru7luld
