dllrruullddrr3u4r3u8l5dlddr6u5drruurrdd3l3r3u4r3u7lulld8r7l5dlddr6u5d4r4ull3durrdd3lr4urd7r4ull3d3urr4d6l4r3u7lulld8r7l5dlddr6u5d3rddlurull3r3u6r4ull3d3urr4d5l3r3u7lulld8r7l5dlddr6u5drr4u3rd5r4ull3d3urr4d4lrr3u7lulld8r7l6drr4u4rd4r4ull3duu8l6drr4u4rdrrllulld3rlu4ld4r4l3drruuddlluururr3l3drruulur
