u7r6(dr)r5(ul)u10lr3u6lulldr10drr8u3r3dlddrrullr3u11r4(dr)dd5(lu)d3(rd)rr4(ul)u10lr3u6lulldr10drr8u3r6d5u11r3(dr)dd4(lu)drdrdrr3(ul)u10lr3u6lulldr10drr8u3r5d4u11rdrdrdd3(lu)drdrrululu10lr3u6lulldr10drr8u3r3duu11rdrddluludrrulu10lr3u6lulldr10drr8u3rddu11rddluru10lr3u6lulldr10drr6urrddlruull4duurrdrru3lruurdu3l3durrdrru3lruulldd4u3r3dlddrru3lr5drruuludrddll6urullrruu3l2(ddrr)dldl3urullrrurr3u6lul10dldrr
