urruu3r3(dr)rurdluululu3(ur)uulurdlldldl3(lu)lldlurddrdrddldldururuu3(ld)duururuuldldduuruuldd3u3r3(dr)rururrd3(dl)ddrdrdd2(llululu)drdrddluludrddluru3r3(dl)rururrdldlr3u3ldrdrluur3(rd)rruululdllullddrd3r3luruuldldru3r3u3(ru)ulldldl3(lu)llddrdr3d3ululuulluur3du3r3(dr)r3(ul)lrrdrdrrulullrrdrrull3r3dldldl3d3luul3urururldldllururldllurdr4drdd3r3ururur4urrd3lr3dldldl3d4luudd4ru3l3ru3(ur)uulldl4dlddrrullr3(ru)uddldlddruruudd3l3urdrdull3urdrduluurdll6drrdruu3drddl3ulu5lurrdruud3l3drrudrr4l3u3rdlddrruruldrrdluluu4ld3ldrd3rlulruurrdluldu4rdlulld3lurrl3drululldrlld3r
