2(r3dlu)rd3rddrruulrddllurd3lurldllur3ldrdrur3ullddrudd3ruullrrddludllur3ldrdrur5ullddrul3drudd3ruullrrddludllurll3urrddlu3d3ruullrrddludllur3ldrdrur3ullddrudlldrdru3ruulldrl6ulldd2(rul3d)ru3dluluru3rddllurll3urrddluddlldrdru5ru2(ulldrl)uullddru3dluluru3rddllurlddlulur5urrddlur3dlud4rddllurldllur3ldrdrur3ullddrudd3ruullrrddludllur3ldrdrur5ullddrul3drudd3ruullrrddludllurll3urrddluddlldrdru3ruulldrluullddru3dluluru3rddllurlddlulur
