dll4ur3u5rddluu7lulld5r4l4dlddr5u4drrdrdrrululuululrdrr3u3lulldr4dlddrurrdru3l3urrdrr3u3lulldr4dldr3urrdrr3u3lul3d3r3lddlddrurrdrdrrululuululluu4rddlruu4l4dlddr5u4drrdrdrrulul3ull3ruu3lulldr4dlddrurrdruud3l3u4ruu3lulldr4dld3rdru3l3u4ruu3lul5dld3rdrdrrulu4ldlu5rddluru4l5u6rdrrdrrullrr3dllulldrruuruuldulldrduurrdlrdlddlddr4urrddlruulldduuruuldulldrurrdr3d4lururrurdluuldulld3rlldrrllddruulurl5dr4uluu6lul4d
