4ruurrdrddl3dlu3dr4drrddldllu3lur3ld4lddl3(lu)urdr3uruul4ullu3(ur)rdld3rdrru4rdrrddllulurddr3dr4dlddllu3ld4lull3urdd4ul4ullu3(ur)rddrrdrrurrdrrddr3dr4dlddllu3ld4lddlluurluullddrluu3r4uluur4dlduuruul3ulluurrd3urrddl3rdrru3l5rdrrullrr3dr3dr4dlddllur4ldllu4rdl5rddlludrr4urrddlruulluuluur3d3uluurd3ulruurrddlruu4luurrdull3dllur3ldllurd3r
