r3ulu4rururrdr3dl4drrurdrrdruud5lddrulu5rdr3uldd4l3drrululu3rdr3urullr3d3l3dluulu4rdr4urullr4d6l4ur3ululldld3l3d3r3d8rdr5uruudl5d6l4urrdlul3dld6rdr4u3d3lulld4l3u3l3u3rurrdrluurdr3dl3dld7rdr6udl4d6l4urrdlul3dld6rdr3udd9lurrlluu3l3u3rurrdrurdrrulrruulldurrddldllddl3dld7rdr4ul3d6l4urrdlul3dld7r9ldd4rludlluru6rdrruuld3l3dluulu4rdr4urdl3urddl3d3ldd3lulu7r3lu7lurdd8rdr5u4d6l3ur3uluur4drdlul3dld6rdr4u3d6l3ur3urrulrruulldl4drdlul3dld6rdr3udd6l3ur3urrulul4drdlul3dld6rdruud6l3(3ur)drdllul4drdlul3dld6rdru6l3ur4u4ld3l3drrurddld3rlluu3l3u6rur3dl3dld6r5l4urrdlul3dld5r
