dlld3ldldd4r3drlluruu5ldd4r4luu5rd3(dr)3udd3ruru4ruu4l3urdldd4rdd4ldld5lulldrrl3ulldru3luuru3ru7r3drdu3r5dllu4lrruuruul3u7lddlddrd3(dr)uuddr4u3d5rdrru6lrruuruul3u7ldl3dldrdd3rdrr3ulurulur5d3ruu3rlluu3r3drd7lrruuruuluu3rdu3lu7lul5drddrddrr4u4dr3udd7r4urul3d3luurr3luu3rdr4drd7lrruuruul3u8l4dldrdd3rdruuddru2(ulur)ul5d4ruuruurrur4drd7lrruuruuluurdldrl3u8l4drddld3rdr5u5dr5u4d3ruuruurrur4drd7lrruuruul4ur3dldr3u9l4d3ld3rurddld3rdr4u4dr4u3d3ruuruurrur4drd7lrruur4urdluu9l4dllddrrurdld3rdr3u3dr3udd3ruuruurrur4drd7lrruur5u9l4d4ldd4rurdld3rdruuddruu
