dd3r4(ur)r3(dl)d4lulldr3u3l4drd3ruu4rururuu3(ld)ururrdldld4luuluurrdlulddlddrl3ull4drd3ruu4ruruuldldurrdld4luuluurrdluldl3drl3ull4drd3r4udd4ruuldrd4ldd3lul4urr3drl3ull4drd3ruull3ururrd4lul4d3urr3drruldluudrrulullul3duu3rurrd4lulddu3rddlurulluld
