u3l3u3ldllrdd3lulddu3ruurrurruuluu5ldrddrrddu4r3d6lruurrd4lddl4udd4r3ull3urr5drd4ldluud4r3ulluurur5du4r3d7luld9rdd4lud4ruuruld7l3ru4ldlu4r6urrdlul5drd4l2(3ruu)llul4du4rddrd8l4ru3lrr4urd3urr3dllul3drdllr3urrdlul3drd3l6r3u3lul3drdll
