dldlurruurur3dldlluluururdurluuluurdrrd5rdr7d3lruullddlddrdd8luurruu5lul7u3r3ldrl6drd5rddllddrudruudd6ruuldrdluuruu4rulruulddrdllrr7uru4ldrrurdu4luulldll3drdrdrrurddu3ldluddldduuluur4u4d4r8ldll3(uru)uluu8rdduulduldduu6lddrulurddldd4l7dld5rlulldl5uruulurrldl4d3u3rdd3rdrru4ldluud5ruurdrd6l
