lu3(lldd)rrdd3(rruu)lld3ullddr3lddrrudrrddllu3dlluur3luurrdullddrdrd4r6uruu3luull5d5urrdd3rddl6d4lulul4url4drdrd4r6ur2(rddl)r4urrddlr4urrddrr4dldld4lud4rururuu3l3ruulld3ulldd2(3luu)llddl2(luur)uru4rddrrdd4rddlldd3luu4l4rdd4rluurruu7lrdu6rddlldd3luullruu4r3d3ull4u4rdrdr4d2(lruu)lulull3d3ullddrlddllu3d3rl3u3dlddr3u3dll3u
