rr4d3r5urur4drd3ldluur3ululld4rur4drd3luldrdlr5u3ldurr3ulldrurd2(dull)d3rd3rur4drdllr4ull3dlddruul4dllulluulu3luuluurdrrd4ruruurdu3ldrrd3rur4drd3luldrddldll7uruurdld3rur4drdllr4u5l7drruruuldu3r4u3luu3ldrurdld4rur4drd3ldlu3r4u5l7drrudllulluululldrdrluurdrdulldrdrrll3u3luuluurdrrd4ru5r4dllddldll7uruulldrrl7d3luurdldrrll3u3luuluurdrrd4ru5r4dllddldll7u5r4d3ldu3r4u4luurdld3rur4drd3lrr4u3luu3ldrurdld4rur4drdllr4u5l5drrllddrru
