l3ururdrud3lddlluluuddrddluddrdldlddrrdd6ruulluurdu3luul3rd4ud5l5dldll6u3rd2(rul3d)ru4d4r3urul4d2(rruu)llrdu3rddlr10ulluu10lddll4d6ruulur2(drrd)drdu3l6d4ruurr4ullulrdrr4ulldd6u6l3dldru3lddururr3d4rurldll3urrdur4lr3dll5dlrrl3u3lddldd2(lluurr)ll4urrll2(uurr)dduu4r2(dduurr)ddrr10dlldd6luudd4luu
