u4lddrrdrdlldlu3rdld3(dr)u3ldrl7ulluull7d3r3l7u2(rrdd)ll3udrr5d4l7u13rllddrd5r3d7r7u4ldd3l3u3l3du12l5drl5ull7d4ruurulldl4udrr5drddl4udd4l7u13rlld2(d3rurddl)d7rurrddl4urull3u4ldd3l3u3l3du12lddrrdrdlldl4udrr5d4l7u13rlld2(d3rurddl)d7rurrddl4ul4u4ldd3l3u3l3du14l6dr3drururrddl4urulldl4udrr6d3lul7u13rlld2(d3rurddl)d7rurrddl3ul5u4ldd3l3u3l3du14l7d3rdr3urulldl4udrr6d3rdrdrrulu4ldl4udd4l7u13rlld2(d3rurddl)d7rurrddluul6u4ldd3l3u3l3du12lddrrdrdlldl4udrr6d5rddluru4ldl4udd4l7u13rlld2(d3rurddl)d7rur3duul7u4ldd3l3u3l3du12lddrrdrdlldl4udrr6d4rdd3rdrrulu3ldlu4rddluru3lu4ldl4udd4l7u13rlld2(d3rurddl)d7rurdl7u4ldd3l3u3l3du12lddrrdrdlldl4udrr6d5rddluru4ldl4udd4l7u13rlldd3rurddld3rdd7r7u4ldd3l3u3l3du12lddrrdrdlldl4udrr7d3rurrddluru4ldl4udd4l7u13rlldd3rurdd3rddld7r7u4ldd3l3u3l4duu12lddrrdrdlldl4udrr7d7rdd3rdruruuld3ldluru3ldlud6rddruru4ldlu4ruuluur3drd4lu3lu4ldl4udd4l7u13rllddrd3rld6rlldd6r7u4ldd3l3u3l3du12lddrrdrdlldl4udrr6d5rddlu4rddluru3lu4ldl4udd4l7u13rlldd3rurddld4rdd6r7u4ldd3l3u3l3du12lddrrdrdlldl4udrr6d5rddluru4ldl4udd4l7u13rlld2(d3rurddl)d4rdrrur7u4ldd3l3u3l3du12lddrrdrdlldl4udrr5dlldd5rurrddluru4ldl4udd4l7u13rlld2(d3rurddl)drrd4rur7u4ldd3l3u3l3du12lddrrdrdlldl4udrr5d4l7u13rlldd3rurddld3rurdlddrd5rur7u4ldd3l3u3l3du12lddrrd3rd4ldl4udrrd3r3drruu5l3d4l7u13rlldd3rd3r3drd5rur7u4ldd3l3u3l4duu12lddrrdd5ru4ldlldl4udrrdrdl3d4l7u13rllddrd3rdrrddrd5rur7u4ldd3l3u3l3du12lddrrddldl4udrrd3r3drud3rdrrlluurdldruu3lu5l3d4l7u13rllddrdrrd3rddrd5rururru2(lrdd)l3ululuur3u4ldd3l3u2(3ldd)rdrrd3rddrd5rur6urul6drrulr3dlulldllu3r4uddrrdlrddluudlld4lu5rurd8luurdld5r4luururrdduulld4lullulluu4r3dld3rurrld3lullur3luu3rdduu12lddrrddldl4udrrd3r3druru5l3d4l7u13rlldd3rurddrrdrdldrd4rurruuluuruuruuld3lulldrdd3l3u3l3du12lddrrddldl4udrr5d4l7u13rlldd3rldrdrrurd3lurudd3r3d4rurruuluuruuruuld3lulldrdd3l3u3l4duu12lddrr6d4rdd7r4u3ldluru3ldlud7rddluru3ldludrrurrddluru3lu3lu6ldl4udrr5d4l7u13r11lddrrd3r3dru4rddluru3lu6ldl4udrrd3r3druru5l3d4l7u11rdd4rdld4r3d4rurruuluuruuruuld3lulldrdd3l3u3l4d3luurr11lddrrddldl4udrr5d4l7u11rdd3ruu13lul5d4u11rdd4rddluu3luu4rdu4ldd3ruru14lul4d3u14r4d3rulldl3uru14lul3duu14r4d5ru4ldl3uru14lulddu14r3d4r4drruldl3uru4ldl3uru14luld14r3d4r4d4ru3ldl3uru4ldl3uru14l13r3d4r3d6rurrd7ldl3uru4ldl3uru13l12r3d4r3d8rddluru7ldl3uru4ldl3uru12l11r3d4r3dluuru3ldl3uru11l10r3d3r3d7ruuluur3drd6ldl3uru4ldl3uru10l9rdrdlddrruldl3uru9l8r3d3r3d7r6uruul7drd6ldl3uru4ldl3uru8l7r3d3r3d4ruullrru6ldl3uru7l6r3d3rddruru4ldl3uru6lrrddrdrurrddl3urul3d3r3d7r7u3lulldrdd3l3u3ldd4lrdd3ruru4lddrd5r3d9r3ulddrd7ldl3uru4ldl3uru3lrr3d3r3d7ruuluur3u3luld4r3dllurdruuru4lulld5r6drd6ldl3uru4ldl3urullruu3r3d3rud3l3u3l5d3r3d7r7u3lulld3rlldd3l3u3l5d3r3d8rddlddr3urullrr4uldl3u6d5ldl3uru4ldl3urul
