9luu4r2(urd3l)url3d18r10u14l2(dru3l)dru4rddrluu13r10d18luu5ruuru2(uluddl)ululudrddlu18r6d18l4ud2(d3rul)d4ldd18r6u12ld2(lldu)l3udd17r4u15l3d3u15r4d15ldll3url3drr3uddl16r4u17ldu4r3d3u13r4d13ldll3url3drr3udd13r4u15ldu15r4d14l14r6d18luurruudd3ruulur3dluuruu13r4u13l3d3u13rdd2(12l12r4d)18luurrurd3lurl3d18ruu17l17rdd18luu
