sprites = {
	["player"] = {},
	["target"] = { type = "target", },
	["package"] = { type = "package", },
	["package-delivered"] = { type = "package", },
	["package-deadlock"] = { type = "package", },
	["deadlock"] = {},
	["tile-background-01"] = { type = "ground", },
	["tile-background-02"] = { type = "ground", },
	["tile-background-03"] = { type = "ground", },
	["tile-background-04"] = { type = "ground", },
	["tile-rock-01"] = { type = "solid", },
	["tile-rock-02"] = { type = "solid", },
	["tile-rock-03"] = { type = "solid", },
}
