lull3dldrru3r3drrdru3ldru5rurddrddlluuru6ldl3ulurrl3d6rddluru5ldl3ululldr4drd5rdrd4rur4uluulu3ld3lu5ldl3ulururrdlul4dldrru4ruurrdluldrd5ldl2(urrd)3lu5rd3ru3rdrddr4dld4lulu5lul3u3drd5rdrd4rur4uluulu3ld3lull3d3rdrurrddluru5ldl3ulurr4ldr4drd5rdrd4rur4uluulu3ld3luluurrdldll3d3rd5rdldluuru6ldl3ulurrl4d4rurrddluru5ldl3ululldru3ldr3ulururrdlul4drr5drd5rdrd4rur4uluulu3ld3lu5l5ruruuldldurrdld4l4ruuldrd3lrdl
