d3(dr)rdd3l3ruulldul3ruuldr3uldr3dlu3l3urddurrdu3r6drddl7u6d11ldllu12r11l7uluur8d7u4rdrdrruuld6rurrd6l4r6drddl7u6d11ldllu12r11l8u4rdrru5l7rdll6rurrd6l4r6drddl7u6d12l7uluurd8rdrruld3rurrd4lrr7d12l7ulu4r
