5rurrd6l3rdduurrddrdl3u5lulld6rur3duullddluru3lulld6rll4druu4drddl4u3d3l5uludr5d3r3uluur4drd3lrr3ul4urrurrdlddrddlulluluurrl4dluuruururrdlddrd3l3urur3drdl3u5lulld5rddlur3dluuruururd5lulld5r4lddr4dlddr4ul3u3dr3d3r3uluurd3ururrdlddrddlulluldr3ururrdlddrd3l3ururd5lulldr4dr3d3r4u4d3l3uluur4dld3rll3ul4u5rurrdlddrddlull3drddl3udd3l3ul4u5rurrdlddrdllr3u5lulld6rur3drdl3u3ld
