lluururdlldd3rdrdrrulu3(ul)ldldd3rdrlu3luururrdldurrdrddllu3luururddurrdrddllulld3(dr)uudlluluuruurrdrddrdl3u2(lullddrdr)rurudldlluluuruulldlddldrrdrull3ururrddlluu4rdrru3luldlldld4rdrdrruluulu4ldd3rdrdrullu4ldldrrd3rdruud4luluu4rdrlu3lu2(urrd)rru3luldlldl3drd4ruulullrrdrdrruluuru3l
