lu6l4u9l4drruurdl5dllulldllddrdrdd8ru10ruruuldldurrdld8ldll8uluulullddll4u9r11d5urururrd3ldllururrll4u9l4drruurrdluldu3ru4dr8drrur6uru3rurrd4lurrd3ldllururrll4u12luld4r4drdrruulurrl3dllur4dllur3ldllddrd4r3u3dllurdrud4luluurrurrdrr3uruurruu4dr8d7ldluud10rulrr6urul5u9l4drruurrdruu4dr7drd8ldlu8ru8rururrdld9lrr12u4l5dr7d10ruuldrd9l8ruu4rd3luldrd8ldllu4rlld9ldllu9rdrulu3r12u4ldd3lddll4u7rll3drruldluud3lddll4u6rldd3l3druulurrdruu4dr7drd8ldllu9rdrulurrll7uluu3l5dllurdr3ull5ul6r2(ddll)r3d4ldllddrdrdururruulurdr3ull4ulu4r3l4drr3dl4drruldllr3ulurdr3urullrrulurrdruu4dr8d7ldllu9rdru9luulu3rdr3ulurdr3ull4ulu3rll4drr3d4ldllu5rdr3urulurldlr3dl4dlluldduuluulu5rdr3ull4ulurrl4drr3d4ldrr3ldd4ruulurdrurrdll3urulldl4ulur3lddlluu4rllddlulu3rl5d3rurr3d5l3d4ruulurdr3uruluurdduurrdluldrrddr7drd8ldllu9rdru
