4(rddr)r3dluludldllurruuldrddllurdrul3uludldllurruuldrddllurdrrlul3uludldllurruuldrddllurdrrlul3uludldllurruuldrddllurdrrlul3uludldllurruuldrddllurdrrlul3ulldrl3urd3uluurdrrldullddrdr16(rd)rul15(lu)llulur3ldrdr3dllurdruluururuuldlduru3rurrdlldlrdruluurrdluldr3drdurul3rdllddruluurrdluldr3drdurul3rdllddruluurrdluldr3drdurul3rdllddruluurrdluldr3drdurul3rdllddruluurrdluldr3drdurul3rdlldduurrdl
