textures = {
	["tile-background-ice-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.5625,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-02-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-03-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.875,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-04-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.75,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-05-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.625,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-06-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.5,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-07-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.375,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-08-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.25,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-big-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["tile-background-ice-cave-art-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.125,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-cave-art-02-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.4375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-window-01-off"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.875,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-window-01-on"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.75,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-window-02-off"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.625,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-background-ice-window-02-on"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.5,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-cave-ice-01-off"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.7470703125,
		x1 = 0.1220703125,
		y1 = 0.06103515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 125,
		trimmedheight = 125,
		untrimmedwidth = 125,
		untrimmedheight = 125,
	},
	["tile-cave-ice-01-on"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.375,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-cave-ice-02-off"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.68603515625,
		x1 = 0.1220703125,
		y1 = 0.06103515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 125,
		trimmedheight = 125,
		untrimmedwidth = 125,
		untrimmedheight = 125,
	},
	["tile-cave-ice-02-on"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.25,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-geyser-ice-01-active-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.875,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-active-back-02"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.75,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-active-back-03"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.625,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-active-back-04"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.5,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-active-back-05"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.375,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-active-back-07"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.25,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-idle-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.125,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-idle-back-02"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-idle-back-03"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.875,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-geyser-ice-01-idle-back-04"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
	["tile-ground-ice-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.125,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-ground-ice-02-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-ground-ice-03-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.875,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-ground-ice-04-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.75,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-ground-ice-05-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.625,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-ground-ice-06-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.5,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-ground-ice-big-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["tile-ground-ledge-ice-DIR-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.375,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-ground-ledge-ice-DIR-02-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.25,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-lava-ice-DIR-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.125,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-lava-ice-DIR-01-back-02"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-lava-ice-DIR-02-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.625,
		x1 = 0.1220703125,
		y1 = 0.06103515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 125,
		trimmedheight = 125,
		untrimmedwidth = 125,
		untrimmedheight = 125,
	},
	["tile-rock-ice-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.875,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-ice-02-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.75,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-ice-03-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.625,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-ice-DIR-04-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.5,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-ice-DIR-05-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.375,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-ice-big-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["tile-rock-shim-ice-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.25,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-slope-ice-DIR-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.125,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-rock-slope-ice-DIR-02-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-waterfall-ice-01-back-01"] = {
		image = "caveexpress-environment-ice-big",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 256,
		untrimmedwidth = 128,
		untrimmedheight = 256,
	},
}
