d3lruulldldllururrdrdll5ruul3ulld5ldl6du8rudrrduruu3r3ldd11l5uru5ru6rurrddr4duul4ull3dld3rll3u4l3drddl4u6d8l5uru5ru5r3l7d3ruu4ruul4ulldurrdd4rurrd5l4rddldlddll4ulu4rurd4l4d4ldd3l7u4rddld3rll3u4l7d3ruu4r3ulu4rurrd5l5drruururudldlddldd3ldd3ruddu3rddlulrr3ulldrurd3ld3luurdrll3drruldlud6l3ulldru3ldrddlluluuld4l3urrdduull3d4rdrudrdrr3u5rdrruluu10l3d4luururddullddrr3u11rluullulul2(ldrr)lu3ld3r
