4rd3(dl)d3(ur)r4(dl)rururuu4(ld)dld4rdru4l3urururr3(dl)ruruu3(ld)dld4rurd4l3ururrdldlruuldldduurrdlullddrulur2(rdrulu)rdr5udlluurrurrd4lulddrdrrddl3d4l3d4rururrdld4ldl3ulur2(rdrulu)rdr5udlluurrurrd4luld3r4dl3d3l3d5ruuldrd4ldl3ulur2(rdrulu)rdr5udlluurrurrd3lr4dl3d3l3d3rddruluurrd4ldl3ulur2(rdrulu)rdr5udlluluurdrrddllulur3dluudllurrdru
