rdrr3u5ldduu5r3dllur3lulu4rdrr3u4ldl3drrdrrudlluruullu3(ld)4r4lddldd4ruruuru4luu4rdulluu4r3dlr3u4lddlldld4r3dld4luurrudlldd4rur3u3l3rdrruldlddld4luurr4urruu4rddlldurruu4lddldl3dllurdrull3d4ru2(ruur)3u4ldlddllddrdrrllulld3r3lddrulur3ururruu4r3dllullrrdrru3l3ruuldrdl
