textures = {
	["npc-flying-falling-DIR-middle-01"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.8671875,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-falling-DIR-middle-02"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.794921875,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-falling-DIR-middle-03"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.72265625,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-falling-DIR-middle-04"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.650390625,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-falling-DIR-middle-05"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.578125,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-flying-DIR-middle-01"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.505859375,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-flying-DIR-middle-02"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.43359375,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-flying-DIR-middle-03"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.361328125,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-flying-DIR-middle-04"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.2890625,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-flying-DIR-middle-05"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.216796875,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-flying-DIR-middle-06"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.14453125,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-flying-DIR-middle-07"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0.072265625,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
	["npc-flying-flying-DIR-middle-08"] = {
		image = "caveexpress-npc_flying-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.828125,
		y1 = 0.072265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 74,
		untrimmedwidth = 53,
		untrimmedheight = 74,
	},
}
