uuruurrllddldllurluurddldr3urrddllrr4urrurr4drd6ldlu6r6urrdlul5drd5l4urru5rd4rddrd3rurr5u3ldlu4r3d4lud4r3u3lddldr3uldu4r5dlld3lul4urrdrdrrlluluu4r3d3ldluud4r3u3lddldr3uldll4drd3rurr3u3dlld3lul4u3rddrrlluu3l4drd3rurruu4lud4rddlld3lul4urrurddld3rlluu3ldd4ldlurullul5d4ulldll4d4r5ldllu5rlluulldurrddldllu4rl4urrddlruull3dullddrruurr3urr3d4lddll4u3rlddlruull3durrddldlddrululuruu6r3ulldduurrddld4lruurrdrdllruull3durr3urddrd3lruulldduull3duld
