5u5lulrdrruld3ruld7rudllurd3luruulddrdlulddullurluurddldllurdll5d10r5u6l3ulldrrddrruld4rulluurdlddrruld3rull4ruu3ldurdurr3d5lrrddrul3drul7drluurdl3urdrrulldlurullruurdurrdlluluurdldrdrrulrulddldlu3druul4druurrdlullddrul3druu4drruulrulr3d3l5uddlldru3ldru7ldurrdlu3rdlddruulurdruudrrdlrddluururrdluldlddrudrullulur3ldrru4ldrrddluruulldru3ldrr4lu5rlluuldrdlr4u2(l3dr5u)lddulldrrurd4ul3dldr7ullddrluurr5d3ulldrurdrruld3l3u3rdu3l3d3rddlurddldllurlurddrdrrlu3dludllurrdrddlurulullddrluurrdrddlulluurrurd3lddrulurddrr3dluuddllurl3drrudru
