lulu6l6drrdrrullrrurrdllrr3uluuru5lrddll6drddl6u5d3rdlrddluurdrruruululuur4uru4l4dll6drl6ulu3r3u3r5dlddllulrd3rdrddldlluullul4ulurdrul5drddl6ulurrl3drrdrru3lrd3rdrddld3lull8urruurrd3r3(dr)ddlu3ld5l4rddrddldlluullul5u5drddl6ulurdrudruudll3d5r5uru3lrd3r3(dr)d4ldlddruru6l4r5urulld3rdrdrddll3r3dlddlldl4u4d3ldluull6ulurrdrull3drrd5ru6l5r5d3luullul4ulurrl5drddl6ulur3d5ruurdrd6l5r5d3lu3l6u
