3ldlu3ruuluur3drd3ld3luurrdrdllruulldlddrurru3r6uld3l3(dl)l3(ur)rlldldd3(ru)3rur5drd3ld4luu3rdu3luluuru5rur5drd3lrr5u6ldlddr3d3ru3r3ulludrr3d3ld3luurdldrrll4ururu3rur5drd3lrr3ullurur4drdllr5u4ldldlluru5rur5drdl5u6lddrulu5rur5d
