#include "CaveExpressSoundType.h"

namespace caveexpress {

namespace SoundTypes {
SoundType SOUND_WATER_IMPACT("water-impact");
SoundType SOUND_PLAYER_SPAWN("player-spawn");
SoundType SOUND_PLAYER_CRASH_HITPOINTS("player-crash-hitpoints");
SoundType SOUND_PLAYER_CRASH_NPC_FLYING("player-crash-npc-flying");
SoundType SOUND_PLAYER_CRASH_NPC_WALKING("player-crash-npc-walking");
SoundType SOUND_PLAYER_CRASH_NPC_FISH("player-crash-npc-fish");
SoundType SOUND_PLAYER_PAIN1("player-pain1");
SoundType SOUND_PLAYER_PAIN2("player-pain2");
SoundType SOUND_PLAYER_PAIN3("player-pain3");
SoundType SOUND_PLAYER_PAIN("player-pain", false, 3);
SoundType SOUND_NPC_FLYING_SPAWNED("npc-flying-spawn");
SoundType SOUND_PACKAGE_COLLIDE1("crate-hit1");
SoundType SOUND_PACKAGE_COLLIDE2("crate-hit2");
SoundType SOUND_PACKAGE_COLLIDE3("crate-hit3");
SoundType SOUND_PACKAGE_COLLIDE4("crate-hit4");
SoundType SOUND_PACKAGE_COLLIDE5("crate-hit5");
SoundType SOUND_PACKAGE_COLLIDE("crate-hit", false, 5);
SoundType SOUND_STONE_COLLIDE("stone-hit");
SoundType SOUND_FRUIT_SPAWN("fruit-spawn");
SoundType SOUND_FRUIT_COLLECTED("fruit-eat");
SoundType SOUND_PLAYER_LAND("player-land", false, 3);
SoundType SOUND_PLAYER_LAND1("player-land1");
SoundType SOUND_PLAYER_LAND2("player-land2");
SoundType SOUND_PLAYER_LAND3("player-land3");
SoundType SOUND_WATER_LEAVE("water-leave");
SoundType SOUND_WATER_RISING("water-rising", true);
SoundType SOUND_MUSIC_WIN("music-win");
SoundType SOUND_AMBIENT_CAVE("cave", true, 2);
SoundType SOUND_AMBIENT_CAVE1("cave1", true);
SoundType SOUND_AMBIENT_CAVE2("cave2", true);
SoundType SOUND_AMBIENT_WATERFALL("tile-waterfall", true);
SoundType SOUND_NPC_CAVE_WATER_RESCUE("npc-cave-water-rescue", false, 3);
SoundType SOUND_NPC_CAVE_BOARD("npc-cave-board", false);
}

}
