#pragma once

#define MAX_HITPOINTS "maxhitpoints"
#define DAMAGE_THRESHOLD "damagethreshold"
#define REFERENCE_TIME_FACTOR "referencetimefactor"
#define FRUIT_COLLECT_DELAY_FOR_A_NEW_LIFE "fruitcollectdelayforanewlife"
#define AMOUNT_OF_FRUITS_FOR_A_NEW_LIFE "amountoffruitsforanewlife"
#define FRUIT_HITPOINTS "fruithitpoints"
#define WATER_PARTICLE "waterparticle"
#define NPC_FLYING_SPEED "npcflyingspeed"
#define GOD_MODE "godmode"
