ru3rdru4lddrrudlluurrddlu3ldrr5luld4ruulldurrddlluurd3rullr4d2(rddrruur)rdd4ulldurrddll4urr2(uull)d3(dlluulld)d2(llddrrdd)ll4ruurrdd4ruu6ldd4r8lddlluu8r6lddlulu6rlluulldurruudd4l2(uurr)uulluuddrrddll4drr3u6rdrdd8lr3u6ruruu7l5d3ullddrluurrd6rdrdd5l4dlludrr4u4r4dll3u3drr4u4lddrluu4r4dll3u3drr4u3l3rddlrddll3udrruull4rdd3lrddll3udrruu4r4dll3u3drr4u4l4rdd3lruuluuluur3d5u5ruu2(rrdd)ll6dlluu5l3u3ldrrur3u5ruu2(rrdd)ll6dlluu5luurulldllulld4rull3r3u5ruu2(rrdd)ll6dlluu5luurull4rdllul3u5ruu2(rrdd)ll6dlluu5luulurrl3d5rddrr5ulld4l4rurr5dlluu5luudd5rdd3l5ruu5l5r4dll3udrruu4l6rdd3lrddll3udrruu3lrdd6rddlludrruu5lrddll3udrruullrruu4rdd5lrdd4rdldl3udll4u4rdd4l4urruull7d5urr5dull8urr7d5urrdd3lruull5duulldllu3rld4luuluu5ruurr5d5ullddrluurr3durr4urrddlruull3dulldd4luu4ldd6ruu4ruurdrd4lddlluu3r3luurrdull4d5lddlddr3u3d5lull3u13r6l4d3ruulldluu3d5lull3u12r4l4urrddlldd4ruu4ld2(drru)ulldd3ldd3rdrru4ldluu3d5lull3u11r4ldd3rdlldl3u3d5lull3u10r6l4urr3d3ull4d4l3drrd5r4ulr4d5lullu4luu6ruulldd4ldd4rdrrd5r4ul4ull4dllrr4urrddlrddr4d5lullu4luu4ruurrddrruull4rdd3l4r4d5lullu4l2(uu4r)dd3r4d3luurrdruu3d5lullu4l2(uu4r)dd4r4urr4d6l3rdd3ldrrdr3u3d5lullu4l2(uu4r)dd5r3l4ull3durluurr3du6ldd4ldd4rdrrd5r4ulrruullrruurrddllddl4d5lu4rdr3udd7lu4l2(uu4r)uurr4drrl3d5lu4rdruudd7lu4l2(uu4r)uurr4d2(rluu)llddrluurr3du6luurrdulldd5r5lddlluurr3du4lddrrudll2(uurr)ddlr4urrddlruull3du4luurrdulldd3r3lururd
