-- create a new campaign
local c = Campaign.new("thirdice")
-- set an ingame icon for this campaign
c:setSetting("icon", "icon-campaign-ice")
-- set the on screen message when this campaign is activated
c:setSetting("text", "ThirdIce")
-- now add all maps
c:addMaps("third-ice-01")
c:addMaps("third-ice-02")
c:addMaps("third-ice-03")
c:addMaps("third-ice-04")
c:addMaps("third-ice-05")
c:addMaps("third-ice-06")
c:addMaps("third-ice-07")
c:addMaps("third-ice-08")
c:addMaps("third-ice-09")
c:addMaps("third-ice-10")
c:addMaps("third-ice-11")
c:addMaps("third-ice-12")
c:addMaps("third-ice-13")
c:addMaps("third-ice-14")
c:addMaps("third-ice-15")
c:addMaps("third-ice-16")
c:addMaps("third-ice-17")
c:addMaps("third-ice-18")
c:addMaps("third-ice-19")
c:addMaps("third-ice-20")
