r3dr3(ru)dlddruruuldrdluldrd3ldl4ulluurrdrdl3d4r3urru4(ul)l3(dr)3drdluldrd3ldl4ulldluururrdrdl3d4r5ululuurdr5drdluldrd3ldl4ulluurrdrdllruulldllddrrurr3d4r7ulldrur5drdluldrd3ldl4ullulluu3rdrdrdllruulu3lddrrdrr3d4r3urruulul4drdluldrd3ldl4ullullddrul3u3rdrdrd4l3ruulu3l2(3d4r)3urrulul3drdluldrd3ldl4u4l3u3rdrdrd3luld3ruululduld
