luld4rurrdl3d3lu3lddrururd3lurd5r3u4lulldrddldr3u4rurrdl3d3lulrd3r3u4lulldrddrr3dlddrurruruu3ldduu3rddldll4ulluu4rurrdl3d3lu3lddrururd3r3u4lulldrddldrurrd3r3u4lul3drr3dldlddrururrur4udd3lddldr4ulluu4rurrdl3d3lu3lddrururd3r3u4lulldrddldrurrd3r3u4lul3drrd3rddlddr6udd3lu3lddrurrddldlddrur4u3luruu4rurrdl6dllrr6u4lulldr3drrddldlddrur3u3dllurdruud3r6u4lul3dldr
