r3druuddrr3lddruul7u3r6drrddlu3ldl6u5d3r7ulld4luld4r4drdl6u3r7dlldl6u5d3r7ulld3lulddlrduu3rddr3dl6u3r7drruld3ldl3uruul3u3r6drd3luul3udr4drr7ulld3luld3rddr5dl6u5d3r7ulld3lulld4r4lddrud3lurrurrllddrulurl4dr3u
