3rd3rl3urr4u7lddrrdrrllulluu7rddlldurr5dllddrr4dll4u4d5luurrurrll3u5r3dulld3l4ulld3rl5ulluurr5dulludrr4u3rdurr7dllurdr4u6dlld3l3u3rllu3rld4lurrl5dllddrr5u3d4luulldd5rlddrr4ulldurrddllrru3rurr4udlldrurd2(dull)ulldrrlddllddrrud4ldd7luurrdulldd5ruu5r3luulluuruld5l4duurr3d4udll3u3rdlluluurrdulluurrd3r3duurruu3rluurr3du4luulldd5r3luu7lddrrudlluu5r3l4dlluu7duu3rur3ldl3uddrr5u
