textures = {
	["npc-mammut-attack-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.615234375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.615234375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.615234375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.9228515625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.861328125,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-init-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.7998046875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-init-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.73828125,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-init-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.6767578125,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-init-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.615234375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-init-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.5537109375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-attack-init-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.5537109375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-dazed-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.5537109375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-dazed-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.5537109375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-dazed-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.4921875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-dazed-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.4921875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-dazed-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.4921875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-dazed-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.4921875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-dazed-DIR-middle-07"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.4306640625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-dazed-DIR-middle-08"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.4306640625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.4306640625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.4306640625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.369140625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.369140625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.369140625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.369140625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-07"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.3076171875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-08"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.3076171875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-09"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.3076171875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-10"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.3076171875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-11"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.24609375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-idle-DIR-middle-12"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.4306640625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-knockout-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.4306640625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-knockout-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.24609375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-knockout-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.24609375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-turn-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.24609375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-turn-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.1845703125,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-turn-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.1845703125,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-turn-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.1845703125,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-turn-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.1845703125,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-turn-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.123046875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-turn-DIR-middle-07"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.123046875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-wakeup-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.123046875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-wakeup-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.5537109375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-wakeup-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.123046875,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-wakeup-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0.0615234375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-wakeup-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0.0615234375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-wakeup-DIR-middle-06"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.0615234375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-wakeup-DIR-middle-07"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0.4306640625,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-walk-DIR-middle-01"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0.0615234375,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-walk-DIR-middle-02"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.626953125,
		y0 = 0,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-walk-DIR-middle-03"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.41796875,
		y0 = 0,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-walk-DIR-middle-04"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0.208984375,
		y0 = 0,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
	["npc-mammut-walk-DIR-middle-05"] = {
		image = "caveexpress-npc_mammut-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.208984375,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 63,
		untrimmedwidth = 107,
		untrimmedheight = 63,
	},
}
