textures = {
	["arrow-white-01-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.46240234375,
		y0 = 0.47705078125,
		x1 = 0.08056640625,
		y1 = 0.04833984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 165,
		trimmedheight = 99,
		untrimmedwidth = 165,
		untrimmedheight = 99,
	},
	["arrow-yellow-01-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.685546875,
		y0 = 0.0009765625,
		x1 = 0.08056640625,
		y1 = 0.04833984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 165,
		trimmedheight = 99,
		untrimmedwidth = 165,
		untrimmedheight = 99,
	},
	["barrel-blue-down-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.4248046875,
		y0 = 0.3154296875,
		x1 = 0.0341796875,
		y1 = 0.0234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 48,
		untrimmedwidth = 70,
		untrimmedheight = 48,
	},
	["barrel-blue-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.50048828125,
		y0 = 0.6533203125,
		x1 = 0.02734375,
		y1 = 0.02734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 56,
		trimmedheight = 56,
		untrimmedwidth = 56,
		untrimmedheight = 56,
	},
	["barrel-red-down-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.6708984375,
		y0 = 0.103515625,
		x1 = 0.0341796875,
		y1 = 0.0234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 48,
		untrimmedwidth = 70,
		untrimmedheight = 48,
	},
	["barrel-red-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.95751953125,
		y0 = 0.0009765625,
		x1 = 0.02734375,
		y1 = 0.02734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 56,
		trimmedheight = 56,
		untrimmedwidth = 56,
		untrimmedheight = 56,
	},
	["barrier-red-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.24853515625,
		y0 = 0.41796875,
		x1 = 0.1025390625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 210,
		trimmedheight = 62,
		untrimmedwidth = 210,
		untrimmedheight = 62,
	},
	["barrier-red-race-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.35205078125,
		y0 = 0.41796875,
		x1 = 0.1025390625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 210,
		trimmedheight = 62,
		untrimmedwidth = 210,
		untrimmedheight = 62,
	},
	["barrier-white-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.53955078125,
		y0 = 0.33349609375,
		x1 = 0.1025390625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 210,
		trimmedheight = 62,
		untrimmedwidth = 210,
		untrimmedheight = 62,
	},
	["barrier-white-race-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.591796875,
		y0 = 0.072265625,
		x1 = 0.1025390625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 210,
		trimmedheight = 62,
		untrimmedwidth = 210,
		untrimmedheight = 62,
	},
	["car-black-01-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.4697265625,
		y0 = 0.412109375,
		x1 = 0.03466796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 131,
		untrimmedwidth = 71,
		untrimmedheight = 131,
	},
	["car-black-03-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.10791015625,
		y0 = 0.50390625,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-black-04-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.14306640625,
		y0 = 0.50390625,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-blue-01-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.2158203125,
		y0 = 0.462890625,
		x1 = 0.03466796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 131,
		untrimmedwidth = 71,
		untrimmedheight = 131,
	},
	["car-blue-03-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.17822265625,
		y0 = 0.494140625,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-blue-04-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.25146484375,
		y0 = 0.462890625,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-green-01-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.51513671875,
		x1 = 0.03466796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 131,
		untrimmedwidth = 71,
		untrimmedheight = 131,
	},
	["car-green-03-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.28662109375,
		y0 = 0.44921875,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-green-04-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.32177734375,
		y0 = 0.44921875,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-red-01-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.03662109375,
		y0 = 0.51513671875,
		x1 = 0.03466796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 131,
		untrimmedwidth = 71,
		untrimmedheight = 131,
	},
	["car-red-03-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.35693359375,
		y0 = 0.44921875,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-red-04-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.39208984375,
		y0 = 0.44921875,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-yellow-01-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.072265625,
		y0 = 0.50390625,
		x1 = 0.03466796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 131,
		untrimmedwidth = 71,
		untrimmedheight = 131,
	},
	["car-yellow-03-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.42724609375,
		y0 = 0.44921875,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["car-yellow-04-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.28662109375,
		y0 = 0.51416015625,
		x1 = 0.0341796875,
		y1 = 0.06396484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 131,
		untrimmedwidth = 70,
		untrimmedheight = 131,
	},
	["cone-down-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.9736328125,
		y0 = 0.029296875,
		x1 = 0.0224609375,
		y1 = 0.021484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 46,
		trimmedheight = 44,
		untrimmedwidth = 46,
		untrimmedheight = 44,
	},
	["cone-straight-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.9736328125,
		y0 = 0.0517578125,
		x1 = 0.02197265625,
		y1 = 0.021484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 45,
		trimmedheight = 44,
		untrimmedwidth = 45,
		untrimmedheight = 44,
	},
	["land-dirt-01-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.591796875,
		y0 = 0.1357421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-02-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.5908203125,
		y0 = 0.19921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-03-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.5908203125,
		y0 = 0.2626953125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-04-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.53955078125,
		y0 = 0.36474609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-05-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.072265625,
		y0 = 0.56884765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-06-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.580078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-07-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.1357421875,
		y0 = 0.56884765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-08-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.19921875,
		y0 = 0.55908203125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-09-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.32177734375,
		y0 = 0.51416015625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-10-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.38525390625,
		y0 = 0.51416015625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-11-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.5439453125,
		y0 = 0.4765625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-12-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.60302734375,
		y0 = 0.36474609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-13-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.6552734375,
		y0 = 0.1357421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-dirt-14-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.70849609375,
		y0 = 0.05029296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-01-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.654296875,
		y0 = 0.19921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-02-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.654296875,
		y0 = 0.2626953125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-03-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.44873046875,
		y0 = 0.5263671875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-04-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.28515625,
		y0 = 0.5791015625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-05-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.064453125,
		y0 = 0.63232421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-06-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.6435546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-07-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.1279296875,
		y0 = 0.63232421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-08-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.19140625,
		y0 = 0.63232421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-09-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.3486328125,
		y0 = 0.57763671875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-10-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.53466796875,
		y0 = 0.5400390625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-11-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.44482421875,
		y0 = 0.58984375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-12-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.27734375,
		y0 = 0.642578125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-13-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.064453125,
		y0 = 0.69580078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-grass-14-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.70703125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-01-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.1279296875,
		y0 = 0.69580078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-02-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.19140625,
		y0 = 0.69580078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-03-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.3408203125,
		y0 = 0.642578125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-04-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.59814453125,
		y0 = 0.5400390625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-05-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.607421875,
		y0 = 0.4609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-06-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.66650390625,
		y0 = 0.35888671875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-07-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.72900390625,
		y0 = 0.11376953125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-08-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.783203125,
		y0 = 0.03369140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-09-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.71875,
		y0 = 0.17724609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-10-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.7177734375,
		y0 = 0.24072265625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-11-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.53076171875,
		y0 = 0.603515625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-12-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.43701171875,
		y0 = 0.6533203125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-13-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.27734375,
		y0 = 0.7060546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["land-sand-14-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.064453125,
		y0 = 0.75927734375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["light-white"] = {
		image = "miniracer-0-big",
		x0 = 0.3759765625,
		y0 = 0.220703125,
		x1 = 0.0478515625,
		y1 = 0.11474609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 235,
		untrimmedwidth = 98,
		untrimmedheight = 235,
	},
	["light-yellow"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.3994140625,
		x1 = 0.0478515625,
		y1 = 0.11474609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 235,
		untrimmedwidth = 98,
		untrimmedheight = 235,
	},
	["lights"] = {
		image = "miniracer-0-big",
		x0 = 0.591796875,
		y0 = 0.103515625,
		x1 = 0.078125,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 160,
		trimmedheight = 64,
		untrimmedwidth = 160,
		untrimmedheight = 64,
	},
	["motorcycle-black"] = {
		image = "miniracer-0-big",
		x0 = 0.2626953125,
		y0 = 0.55224609375,
		x1 = 0.021484375,
		y1 = 0.048828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 44,
		trimmedheight = 100,
		untrimmedwidth = 44,
		untrimmedheight = 100,
	},
	["motorcycle-blue"] = {
		image = "miniracer-0-big",
		x0 = 0.2548828125,
		y0 = 0.62255859375,
		x1 = 0.021484375,
		y1 = 0.048828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 44,
		trimmedheight = 100,
		untrimmedwidth = 44,
		untrimmedheight = 100,
	},
	["motorcycle-green"] = {
		image = "miniracer-0-big",
		x0 = 0.51220703125,
		y0 = 0.5263671875,
		x1 = 0.021484375,
		y1 = 0.048828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 44,
		trimmedheight = 100,
		untrimmedwidth = 44,
		untrimmedheight = 100,
	},
	["motorcycle-red"] = {
		image = "miniracer-0-big",
		x0 = 0.2548828125,
		y0 = 0.67236328125,
		x1 = 0.021484375,
		y1 = 0.048828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 44,
		trimmedheight = 100,
		untrimmedwidth = 44,
		untrimmedheight = 100,
	},
	["motorcycle-yellow"] = {
		image = "miniracer-0-big",
		x0 = 0.50830078125,
		y0 = 0.58984375,
		x1 = 0.021484375,
		y1 = 0.048828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 44,
		trimmedheight = 100,
		untrimmedwidth = 44,
		untrimmedheight = 100,
	},
	["racer-black"] = {
		image = "miniracer-0-big",
		x0 = 0.2548828125,
		y0 = 0.72216796875,
		x1 = 0.0205078125,
		y1 = 0.02490234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 42,
		trimmedheight = 51,
		untrimmedwidth = 42,
		untrimmedheight = 51,
	},
	["racer-blue"] = {
		image = "miniracer-0-big",
		x0 = 0.2548828125,
		y0 = 0.748046875,
		x1 = 0.0205078125,
		y1 = 0.02490234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 42,
		trimmedheight = 51,
		untrimmedwidth = 42,
		untrimmedheight = 51,
	},
	["racer-green"] = {
		image = "miniracer-0-big",
		x0 = 0.41455078125,
		y0 = 0.76806640625,
		x1 = 0.0205078125,
		y1 = 0.02490234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 42,
		trimmedheight = 51,
		untrimmedwidth = 42,
		untrimmedheight = 51,
	},
	["racer-red"] = {
		image = "miniracer-0-big",
		x0 = 0.47802734375,
		y0 = 0.7802734375,
		x1 = 0.0205078125,
		y1 = 0.02490234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 42,
		trimmedheight = 51,
		untrimmedwidth = 42,
		untrimmedheight = 51,
	},
	["racer-yellow"] = {
		image = "miniracer-0-big",
		x0 = 0.47802734375,
		y0 = 0.80615234375,
		x1 = 0.0205078125,
		y1 = 0.02490234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 42,
		trimmedheight = 51,
		untrimmedwidth = 42,
		untrimmedheight = 51,
	},
	["road-asphalt-01-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.7705078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-02-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.1279296875,
		y0 = 0.75927734375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-03-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.19140625,
		y0 = 0.75927734375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-04-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.3408203125,
		y0 = 0.7060546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-05-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.59423828125,
		y0 = 0.603515625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-06-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.65771484375,
		y0 = 0.603515625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-07-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.6708984375,
		y0 = 0.455078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-09-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.72998046875,
		y0 = 0.35888671875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-10-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.7822265625,
		y0 = 0.17724609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-11-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.94482421875,
		y0 = 0.74609375,
		x1 = 0.05029296875,
		y1 = 0.05078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 24,
		trimmedwidth = 103,
		trimmedheight = 104,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-12-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.2158203125,
		y0 = 0.3994140625,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 63,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-13-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.79248046875,
		y0 = 0.09716796875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-14-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.8466796875,
		y0 = 0.03369140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-15-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.5380859375,
		y0 = 0.42822265625,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 63,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-16-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.78125,
		y0 = 0.24072265625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-17-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.6708984375,
		y0 = 0.5185546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-18-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.76708984375,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 63,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-19-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.72119140625,
		y0 = 0.58203125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-20-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.734375,
		y0 = 0.455078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-21-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.79345703125,
		y0 = 0.3369140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-22-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.8447265625,
		y0 = 0.24072265625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-23-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.85595703125,
		y0 = 0.09716796875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-24-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.91015625,
		y0 = 0.03369140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-25-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.845703125,
		y0 = 0.16064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-26-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.734375,
		y0 = 0.5185546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-27-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.72119140625,
		y0 = 0.6455078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-28-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.50048828125,
		y0 = 0.681640625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-29-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.43701171875,
		y0 = 0.716796875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-30-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.2548828125,
		y0 = 0.77392578125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-31-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.064453125,
		y0 = 0.82275390625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-32-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.50537109375,
		y0 = 0.412109375,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-33-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.833984375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-34-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.1279296875,
		y0 = 0.82275390625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-35-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.19140625,
		y0 = 0.82275390625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-36-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.318359375,
		y0 = 0.76953125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-37-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.56396484375,
		y0 = 0.6669921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-38-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.62744140625,
		y0 = 0.6669921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-39-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.69091796875,
		y0 = 0.708984375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-40-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.50048828125,
		y0 = 0.7451171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-41-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.41455078125,
		y0 = 0.7939453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-42-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.2548828125,
		y0 = 0.83740234375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-43-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.318359375,
		y0 = 0.8330078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-44-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.064453125,
		y0 = 0.88623046875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-45-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.8974609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-46-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.1279296875,
		y0 = 0.88623046875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-47-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.19140625,
		y0 = 0.88623046875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-48-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.56396484375,
		y0 = 0.73046875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-49-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.62744140625,
		y0 = 0.73046875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-50-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.412109375,
		y0 = 0.57763671875,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-51-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.75439453125,
		y0 = 0.708984375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-52-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.64306640625,
		y0 = 0.326171875,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-53-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.6015625,
		y0 = 0.42822265625,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-54-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.78466796875,
		y0 = 0.58203125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-55-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.7978515625,
		y0 = 0.43310546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-56-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.85693359375,
		y0 = 0.3369140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-57-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.908203125,
		y0 = 0.22412109375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-58-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.9091796875,
		y0 = 0.16064453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-59-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.91943359375,
		y0 = 0.09716796875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-60-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.7978515625,
		y0 = 0.49658203125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-61-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.78466796875,
		y0 = 0.6455078125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-62-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.94384765625,
		y0 = 0.94091796875,
		x1 = 0.05029296875,
		y1 = 0.05078125,
		trimmedoffsetx = 25,
		trimmedoffsety = 0,
		trimmedwidth = 103,
		trimmedheight = 104,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-63-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.81787109375,
		y0 = 0.708984375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-64-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.84814453125,
		y0 = 0.56005859375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-66-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.404296875,
		y0 = 0.64111328125,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 63,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-67-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.861328125,
		y0 = 0.4287109375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-68-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.92041015625,
		y0 = 0.3232421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-69-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.861328125,
		y0 = 0.4921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-70-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.84814453125,
		y0 = 0.62353515625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-71-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.69091796875,
		y0 = 0.7724609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-72-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.49951171875,
		y0 = 0.80859375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-73-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.41455078125,
		y0 = 0.857421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-74-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.318359375,
		y0 = 0.896484375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-75-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.2548828125,
		y0 = 0.90087890625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-76-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.56298828125,
		y0 = 0.80859375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-77-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.62646484375,
		y0 = 0.7939453125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-78-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.75439453125,
		y0 = 0.7724609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-79-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.81787109375,
		y0 = 0.7724609375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-80-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.68994140625,
		y0 = 0.8359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-81-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.62646484375,
		y0 = 0.857421875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-82-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.47802734375,
		y0 = 0.8720703125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-83-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.41455078125,
		y0 = 0.9208984375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-84-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.54150390625,
		y0 = 0.8720703125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-85-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.75341796875,
		y0 = 0.8359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-86-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.81689453125,
		y0 = 0.8359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-87-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.88037109375,
		y0 = 0.8359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-88-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.88134765625,
		y0 = 0.68701171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-89-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.88134765625,
		y0 = 0.75048828125,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-asphalt-90-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.91162109375,
		y0 = 0.5556640625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-01-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.91162109375,
		y0 = 0.619140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-02-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.9248046875,
		y0 = 0.4287109375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-03-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.9248046875,
		y0 = 0.4921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-04-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.68994140625,
		y0 = 0.8994140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-05-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.60498046875,
		y0 = 0.9208984375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-06-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.47802734375,
		y0 = 0.935546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-08-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.54150390625,
		y0 = 0.935546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-09-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.75341796875,
		y0 = 0.8994140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-11-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.404296875,
		y0 = 0.70458984375,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 63,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-12-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.81689453125,
		y0 = 0.8994140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-13-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.88037109375,
		y0 = 0.8994140625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-14-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.83056640625,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 63,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-17-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.7177734375,
		y0 = 0.30419921875,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 63,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-31-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.3818359375,
		y0 = 0.76953125,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-49-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.3818359375,
		y0 = 0.8330078125,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-51-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.66650390625,
		y0 = 0.42236328125,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-52-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.89404296875,
		y0 = 0.0009765625,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-dirt-65-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.3818359375,
		y0 = 0.896484375,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 63,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-08-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.94384765625,
		y0 = 0.81396484375,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 63,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-11-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.78125,
		y0 = 0.30419921875,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 63,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-14-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.72998046875,
		y0 = 0.42236328125,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 63,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-28-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.94384765625,
		y0 = 0.87744140625,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-46-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.94482421875,
		y0 = 0.6826171875,
		x1 = 0.03173828125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 65,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-48-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.8447265625,
		y0 = 0.30419921875,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["road-sand-49-back-01"] = {
		image = "miniracer-0-big",
		x0 = 0.79345703125,
		y0 = 0.400390625,
		x1 = 0.0625,
		y1 = 0.03173828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 65,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["rock-01-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.9609375,
		x1 = 0.04345703125,
		y1 = 0.03515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 89,
		trimmedheight = 72,
		untrimmedwidth = 89,
		untrimmedheight = 72,
	},
	["rock-02-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.36181640625,
		y0 = 0.9599609375,
		x1 = 0.03564453125,
		y1 = 0.033203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 73,
		trimmedheight = 68,
		untrimmedwidth = 73,
		untrimmedheight = 68,
	},
	["rock-03-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.318359375,
		y0 = 0.9599609375,
		x1 = 0.04248046875,
		y1 = 0.03271484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 87,
		trimmedheight = 67,
		untrimmedwidth = 87,
		untrimmedheight = 67,
	},
	["rock-04-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.92041015625,
		y0 = 0.38671875,
		x1 = 0.04931640625,
		y1 = 0.041015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 101,
		trimmedheight = 84,
		untrimmedwidth = 101,
		untrimmedheight = 84,
	},
	["rock-05-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.12548828125,
		y0 = 0.94970703125,
		x1 = 0.05859375,
		y1 = 0.0478515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 120,
		trimmedheight = 98,
		untrimmedwidth = 120,
		untrimmedheight = 98,
	},
	["rock-08-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.70654296875,
		y0 = 0.3369140625,
		x1 = 0.02099609375,
		y1 = 0.02099609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 43,
		untrimmedwidth = 43,
		untrimmedheight = 43,
	},
	["rock-10-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.685546875,
		y0 = 0.05029296875,
		x1 = 0.02197265625,
		y1 = 0.01953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 45,
		trimmedheight = 40,
		untrimmedwidth = 45,
		untrimmedheight = 40,
	},
	["rock-11-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.55419921875,
		y0 = 0.4609375,
		x1 = 0.013671875,
		y1 = 0.013671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 28,
		trimmedheight = 28,
		untrimmedwidth = 28,
		untrimmedheight = 28,
	},
	["rock-12-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.24853515625,
		y0 = 0.44921875,
		x1 = 0.01416015625,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 29,
		trimmedheight = 26,
		untrimmedwidth = 29,
		untrimmedheight = 26,
	},
	["rock-13-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.4140625,
		y0 = 0.33642578125,
		x1 = 0.0087890625,
		y1 = 0.0087890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 18,
		trimmedheight = 18,
		untrimmedwidth = 18,
		untrimmedheight = 18,
	},
	["rock-14-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.5205078125,
		y0 = 0.33349609375,
		x1 = 0.0078125,
		y1 = 0.00732421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 16,
		trimmedheight = 15,
		untrimmedwidth = 16,
		untrimmedheight = 15,
	},
	["rock-16-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.18505859375,
		y0 = 0.94970703125,
		x1 = 0.05859375,
		y1 = 0.0478515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 120,
		trimmedheight = 98,
		untrimmedwidth = 120,
		untrimmedheight = 98,
	},
	["rock-19-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.728515625,
		y0 = 0.3369140625,
		x1 = 0.02099609375,
		y1 = 0.02099609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 43,
		trimmedheight = 43,
		untrimmedwidth = 43,
		untrimmedheight = 43,
	},
	["rock-20-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.7060546875,
		y0 = 0.11376953125,
		x1 = 0.02197265625,
		y1 = 0.01953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 45,
		trimmedheight = 40,
		untrimmedwidth = 45,
		untrimmedheight = 40,
	},
	["rock-21-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.56884765625,
		y0 = 0.4609375,
		x1 = 0.013671875,
		y1 = 0.013671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 28,
		trimmedheight = 28,
		untrimmedwidth = 28,
		untrimmedheight = 28,
	},
	["rock-22-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.263671875,
		y0 = 0.44921875,
		x1 = 0.01416015625,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 29,
		trimmedheight = 26,
		untrimmedwidth = 29,
		untrimmedheight = 26,
	},
	["rock-23-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0498046875,
		y0 = 0.50390625,
		x1 = 0.0087890625,
		y1 = 0.0087890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 18,
		trimmedheight = 18,
		untrimmedwidth = 18,
		untrimmedheight = 18,
	},
	["rock-24-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.529296875,
		y0 = 0.33349609375,
		x1 = 0.0078125,
		y1 = 0.00732421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 16,
		trimmedheight = 15,
		untrimmedwidth = 16,
		untrimmedheight = 15,
	},
	["skidmark-long-1-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.1552734375,
		y0 = 0.3994140625,
		x1 = 0.029296875,
		y1 = 0.09375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 60,
		trimmedheight = 192,
		untrimmedwidth = 60,
		untrimmedheight = 192,
	},
	["skidmark-long-2-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.185546875,
		y0 = 0.3994140625,
		x1 = 0.029296875,
		y1 = 0.09375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 60,
		trimmedheight = 192,
		untrimmedwidth = 60,
		untrimmedheight = 192,
	},
	["skidmark-long-3-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.4248046875,
		y0 = 0.220703125,
		x1 = 0.037109375,
		y1 = 0.09375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 76,
		trimmedheight = 192,
		untrimmedwidth = 76,
		untrimmedheight = 192,
	},
	["skidmark-short-1-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.4599609375,
		y0 = 0.33349609375,
		x1 = 0.029296875,
		y1 = 0.0078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 60,
		trimmedheight = 16,
		untrimmedwidth = 60,
		untrimmedheight = 16,
	},
	["skidmark-short-2-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.490234375,
		y0 = 0.33349609375,
		x1 = 0.029296875,
		y1 = 0.0078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 60,
		trimmedheight = 16,
		untrimmedwidth = 60,
		untrimmedheight = 16,
	},
	["skidmark-short-3-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.3759765625,
		y0 = 0.33642578125,
		x1 = 0.037109375,
		y1 = 0.0078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 76,
		trimmedheight = 16,
		untrimmedwidth = 76,
		untrimmedheight = 16,
	},
	["tent-blue-large-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.25,
		y0 = 0.220703125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["tent-red-large-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.4658203125,
		y0 = 0.072265625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["tile-reference"] = {
		image = "miniracer-0-big",
		x0 = 0.44482421875,
		y0 = 0.58984375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tires-red-alt-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.69091796875,
		y0 = 0.6669921875,
		x1 = 0.02734375,
		y1 = 0.02734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 56,
		trimmedheight = 56,
		untrimmedwidth = 56,
		untrimmedheight = 56,
	},
	["tires-red-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.85693359375,
		y0 = 0.400390625,
		x1 = 0.02734375,
		y1 = 0.02734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 56,
		trimmedheight = 56,
		untrimmedwidth = 56,
		untrimmedheight = 56,
	},
	["tires-white-alt-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.97119140625,
		y0 = 0.28759765625,
		x1 = 0.02734375,
		y1 = 0.02734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 56,
		trimmedheight = 56,
		untrimmedwidth = 56,
		untrimmedheight = 56,
	},
	["tires-white-middle-01"] = {
		image = "miniracer-0-big",
		x0 = 0.88525390625,
		y0 = 0.400390625,
		x1 = 0.02734375,
		y1 = 0.02734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 56,
		trimmedheight = 56,
		untrimmedwidth = 56,
		untrimmedheight = 56,
	},
	["tree-large-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.0498046875,
		y0 = 0.3994140625,
		x1 = 0.1044921875,
		y1 = 0.103515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 214,
		trimmedheight = 212,
		untrimmedwidth = 214,
		untrimmedheight = 212,
	},
	["tree-small-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.4697265625,
		y0 = 0.34228515625,
		x1 = 0.06884765625,
		y1 = 0.06884765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 141,
		trimmedheight = 141,
		untrimmedwidth = 141,
		untrimmedheight = 141,
	},
	["tribune-empty-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.24609375,
		y0 = 0.0009765625,
		x1 = 0.21875,
		y1 = 0.10888671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 448,
		trimmedheight = 223,
		untrimmedwidth = 448,
		untrimmedheight = 223,
	},
	["tribune-full-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.24609375,
		y0 = 0.11083984375,
		x1 = 0.21875,
		y1 = 0.10888671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 448,
		trimmedheight = 223,
		untrimmedwidth = 448,
		untrimmedheight = 223,
	},
	["tribune-overhang-red-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.25,
		y0 = 0.3466796875,
		x1 = 0.21875,
		y1 = 0.0703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 448,
		trimmedheight = 144,
		untrimmedwidth = 448,
		untrimmedheight = 144,
	},
	["tribune-overhang-striped-front-01"] = {
		image = "miniracer-0-big",
		x0 = 0.4658203125,
		y0 = 0.0009765625,
		x1 = 0.21875,
		y1 = 0.0703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 448,
		trimmedheight = 144,
		untrimmedwidth = 448,
		untrimmedheight = 144,
	},
	["ui/font-10"] = {
		image = "miniracer-0-big",
		x0 = 0.908203125,
		y0 = 0.28759765625,
		x1 = 0.06201171875,
		y1 = 0.03466796875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 127,
		trimmedheight = 71,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["ui/font-12"] = {
		image = "miniracer-0-big",
		x0 = 0.064453125,
		y0 = 0.94970703125,
		x1 = 0.06005859375,
		y1 = 0.04736328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 123,
		trimmedheight = 97,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["ui/font-20"] = {
		image = "miniracer-0-big",
		x0 = 0.462890625,
		y0 = 0.27685546875,
		x1 = 0.1240234375,
		y1 = 0.0556640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 254,
		trimmedheight = 114,
		untrimmedwidth = 256,
		untrimmedheight = 128,
	},
	["ui/font-24"] = {
		image = "miniracer-0-big",
		x0 = 0.4658203125,
		y0 = 0.1982421875,
		x1 = 0.1240234375,
		y1 = 0.07763671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 254,
		trimmedheight = 159,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["ui/font-48"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.24609375,
		x1 = 0.248046875,
		y1 = 0.15234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 508,
		trimmedheight = 312,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
	["ui/font-8"] = {
		image = "miniracer-0-big",
		x0 = 0.21337890625,
		y0 = 0.52783203125,
		x1 = 0.06201171875,
		y1 = 0.0234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 127,
		trimmedheight = 48,
		untrimmedwidth = 128,
		untrimmedheight = 64,
	},
	["ui/mouse"] = {
		image = "miniracer-0-big",
		x0 = 0.9716796875,
		y0 = 0.22412109375,
		x1 = 0.0263671875,
		y1 = 0.0263671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 54,
		trimmedheight = 54,
		untrimmedwidth = 54,
		untrimmedheight = 54,
	},
	["ui/star-bronze"] = {
		image = "miniracer-0-big",
		x0 = 0.5380859375,
		y0 = 0.4609375,
		x1 = 0.01513671875,
		y1 = 0.0146484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 31,
		trimmedheight = 30,
		untrimmedwidth = 31,
		untrimmedheight = 30,
	},
	["ui/star-gold"] = {
		image = "miniracer-0-big",
		x0 = 0.76708984375,
		y0 = 0.03369140625,
		x1 = 0.01513671875,
		y1 = 0.0146484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 31,
		trimmedheight = 30,
		untrimmedwidth = 31,
		untrimmedheight = 30,
	},
	["ui/star-silver"] = {
		image = "miniracer-0-big",
		x0 = 0.2626953125,
		y0 = 0.60205078125,
		x1 = 0.01513671875,
		y1 = 0.0146484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 31,
		trimmedheight = 30,
		untrimmedwidth = 31,
		untrimmedheight = 30,
	},
	["ui/ui-scene-cave-ice"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 500,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
	["ui/ui-scene-caveart-ice"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 500,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
	["ui/ui-scene-player"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 500,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
	["ui/ui-scene-tile1-ice"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 500,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
	["ui/ui-scene-tile2-ice"] = {
		image = "miniracer-0-big",
		x0 = 0.0009765625,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 500,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
}
