ddrdr3(ru)3r3l3(dl)luud4(ru)r4(ld)3ldldlluru3r3ururuul3uddl3ud3rdlullddrdru3d4(lu)r3dl3(ld)3lr3drrulu3(ur)uuld5rddlu4d3lddrulurrlddlldlddlluur3urullr4drddl5urruruuldu3luurdurrdllrruurrd3(lu)3r3lullddrrldulu4rdrrulru4rddrrdduu3l3dllddlluuddrrdrrddrddldld4lulldl3udd3ruddrruld3rulrruruu3l4drdl6ull4durl3urrdlr3drruldlddrruluurruullddrruld3ruld3lddrrul5ururrdldduu3r2(ddll)rr3uluruuruulldr3u4lulurddr3drlldll2(ddur)r5d5uruulduullddrrlur4uruld3r7drd3lrr4drrul2(dluu)dd3rullruul4urrddldlurruuldu3lrruurdu3lrdr4ulddr3urrdlulddurrdllrd
