textures = {
	["dead-hitpoints"] = {
		image = "caveexpress-ui-dead-big",
		x0 = 0,
		y0 = 0.71826171875,
		x1 = 0.3662109375,
		y1 = 0.2021484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 750,
		trimmedheight = 414,
		untrimmedwidth = 750,
		untrimmedheight = 414,
	},
	["dead-npc-fish"] = {
		image = "caveexpress-ui-dead-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.5546875,
		y1 = 0.37353515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 1136,
		trimmedheight = 765,
		untrimmedwidth = 1136,
		untrimmedheight = 765,
	},
	["dead-npc-flying"] = {
		image = "caveexpress-ui-dead-big",
		x0 = 0.5537109375,
		y0 = 0.57568359375,
		x1 = 0.35986328125,
		y1 = 0.3544921875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 737,
		trimmedheight = 726,
		untrimmedwidth = 737,
		untrimmedheight = 726,
	},
	["dead-npc-mammut"] = {
		image = "caveexpress-ui-dead-big",
		x0 = 0,
		y0 = 0.37353515625,
		x1 = 0.5537109375,
		y1 = 0.3447265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 1134,
		trimmedheight = 706,
		untrimmedwidth = 1134,
		untrimmedheight = 706,
	},
	["dead-npc-walking"] = {
		image = "caveexpress-ui-dead-big",
		x0 = 0.5546875,
		y0 = 0.29638671875,
		x1 = 0.41015625,
		y1 = 0.279296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 840,
		trimmedheight = 572,
		untrimmedwidth = 840,
		untrimmedheight = 572,
	},
	["dead-waterheight"] = {
		image = "caveexpress-ui-dead-big",
		x0 = 0.5546875,
		y0 = 0,
		x1 = 0.42041015625,
		y1 = 0.29638671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 861,
		trimmedheight = 607,
		untrimmedwidth = 861,
		untrimmedheight = 607,
	},
}
