luulld9l8rddluru7l8rurrd9l9rddluru8l7rddluru6ldlu8r3dlrrdd3l4uru6lu4l3rd4r3u4rdd3l3ruu4luurrdull4drd4ld4l3ru4ru4ruu3lruull4drd4lu3lrrd4ru4rurru5lruull4drd4ld3lrru4rd4r3uru4lruull4drd4lullrd4r3druuru5ldllru7r3drrdd3l4uru6luldrdl
