d3r3ur3u6rddlrddlur3u8ldrrddlddru3ruruuddrdrrululruu6l3d3u6r4dlulld3lul3dlddrrul3u4ruruuddrr3u5lul4d3u6rddldlld3lul3dllddrudrrul3u4ruruudrruu5lul4d3u4r3dld3luuru3ldldrr3dllddrudrru4l3r3u4rur3u3lddldur3ulddu4r3dld3lul3dlddrrullr4ul3urdrdduruu3r3dld3lul3dldruur3ur3ul4d3u4r3dld3lul3dlddllurluluurddurd
