#pragma once

#include "common/Achievement.h"

namespace cavepacker {

namespace Achievements {
extern Achievement STARS_3;
extern Achievement STARS_10;
extern Achievement STARS_300;
extern Achievement PUZZLES_10;
extern Achievement PUZZLES_20;
extern Achievement PUZZLES_30;
extern Achievement PUZZLES_40;
extern Achievement PUZZLES_50;
extern Achievement PUZZLES_60;
extern Achievement PUZZLES_70;
extern Achievement PUZZLES_80;
extern Achievement PUZZLES_90;
extern Achievement PUZZLES_100;
extern Achievement FINISHED_TUTORIALS;
extern Achievement FINISHED_XSOKOBAN;
extern Achievement FINISHED_GRIGORUSHA;
extern Achievement FINSIHED_KSOKOBAN;
}

}
