lldurrdlu3rdlu4rdllrddluruu3lddrrdru3luurrdldruurrdllddruluu4ldd4ruu6ldru3ldrrlddruluu7r3drruldlu6ldludlu4r2(ddrr)dull2(dru3l)dru4ldrrlddruluu3rddlldlu3ruulldrdluulldrrddluruu4rdd4luu6rdlu3rdllu4rdllrddluruu3lddrrdru3luurrdlu3rdllrddluruu9l3dllurdru8rdrudru
