3r8d3luurrlldd3r6u4dlldldlluluurdll3dru4rl4urdrdruudllull3u8ldlddrr3drdd3luluur4uruulld8r3(urdldr)urdll3u8lu4lddrrlldd3ruulu8r2(urdldr)ur4drrurd5lrrd3ul3u9l5dlu3dr6ulu8r2(urdldr)ur3drrldluul3u8ld4lddrrdr3ulu8r3(urdldr)urdll3u8ld4l3drrdr4ulu8r2(urdldr)ur3drull3u9l7d3lurrdr6ulu8rurdldru8l8d3ruululrdrdd3l7ulu7rurrdrdldrulluruld7l5drruulrddll4ulu8rurd8l3drrdrru3lrddll4ulu8rdrurdu9l8drr4urullrddll4ulu8rdrruldlu7l3drr3druuru3lrddll4ulu8rdrrulld3rdrddluludrrulullrrd2(dlurul)dd3r4dl3u2(ruldlu)d3r6dl5uruldlurulr6d4l3urrdrlull3d4r4urullr3dllulld3r3ldd4r4uruldluur6d3lulu3rlldd3r4uruldlur5dllulurrlddrr4urul3d4rddlurullrddlldl4uddr3uldd4ruuldlldl3udd4r3ulddrd3ldluud3r3uluur4drdllrrd3luddluu
