drr3urrddlrr3dlluulurrl3drr3uluulldurrddl3dldllu4rdrulluulldurrddldllu4rl3uruullddr3dlluuluurlddrddrr3ur4ulldldruurr4dl3drdrru4lr3urrdduul4ullddrluurrddrdd3luuddr3dldlluruuluuru4rdd3lud3ruu3lddr3dldlu3rdrru4l3r3u3lullddrru3r3d3ldllu3ruuddlludrruuluullddrrldd3rdrru3lrr3ullrr3dlluu3luurru3r4d4u3ldlldd3rddldluud3rdrrul5u3ldllddrluurrurruulldldururrddll3r5d3ldlluruur3u3rddllrruu3ldd3r3d3ldluudrruuddrr3ullrruuluulldd3rddlurull
