uu4drd4ruulldu3ruruuldlldurruullddu3lulld4r3l4drdrdrruluuluuddrddrruulrruruuldlldldlurrurruulld3lulldr4drdrdr2(ruruu)lulld3luld4rurrdrddldllulludrrdrruruululld3lulld3rddrrdrddldllulul3u3drdrdrruruuluudlldrl3ululldr4drdrdrruluulur3drruulrddlluul3ulu3lulld3rdr4drdrdrullul4ulu4lddrrud3ldlddrurrudllddrruud3rdrru4l3r4ulululldrddrdduuluullddrlldlddrurrururdlldllddrru3rdrrul4ululul2(ldldd)rdrru3rdru4ldlluluururrdrrdullulldlddrdrrurr3ulr3dlldllul2(uurur)rdlddr3dlldlluluururrdrlduuluururrdlddrdlulluururdllddldlddrurrudllddrru3rdrruldrrdrruruu3l3ull4d4uru3lulldlddldldrddrru3rdru4ldll4urrdrrdulluluururrdrrdrr3d3rddldllulu3l3rdrdr2(ruruu)ldlldldlurrurruulld3lu3lulldlddrdrrddrru3(dr)ruruululludrrdrruruululldll3drl3urrurrdr2(ddldl)luruul3urrurrdrddldlluudlrdrddldlluruulur3dllu3luullull4drrurr3ulr3drrld3rdr3urrddldluudrruull3ruruuldlldl3drruururuluulldduur2(rddl)dd5lu4ldll4uruururrdlddr3dlldll4urrdrluluururrdlddrdduu4l4drr3urldd3r3ldl2(luur)uurur3drdduuluullddrdrluluurrddrdu4l4drrurrlluurldlluu3r
