RurrdddddddllllllLLLdlluRuuuRRlllllddddddrrRRdrruUrrrrrrruullllllllLdlUUUddrrrrrruurruullluuuuLLLLLLdlluurDldRRRurrrrrddddrrrddlllllUUUUUdddddrrrrruullluuuulLLLLLdlluurDldRRurrrrddddddrrrddrrrrddlllllllUdddllulllluuuuuurrRRRlldddrrRRRRRRRllllllddddlluRdrUUUdrrrrrrruUUUUUUUrULuulldddRRuLdlUUUrrdRlddddddddlllluulllUUUUUdddddrrrrruullluuuulLLLrrddddddrrrddllLLLdlUUUddrrrdddlllllluuuuuurrRRRlldddrrrrrruulllUUUUUdddddrrrrruullluuuulLL
