lddllrruu5lulld6r5lddlddr3uddrrdrruuldu3rdrddrddlu3luulrdd3ldllur3u3rdrdd3ldl3ulur3d4ruuluur3d3urruruuld5lulldrddlddrurrll3d4r4uldu3rdrddrddlu3l4urrdrddrd3ldl4u3d3r3ululld4l3d3r3l3u4rurrdr3dlldl4u3d3r3uluuruuld5lulldrddld4r3l3d7r3uluuruuld5lul3dldrrl3d7r3uluuru6lul6d5u6r3dr3d6ldllu4r3l6u6r3dr3dlldluu
