3l5u4ldldll3ulluu6ru3rd12luldrdlu4rddrrudlluu6rurrd11lulddrdluu6r4dlur3ullddrdruudlluu6rurrd12l6r5drr4u4dll5u4rurrd11ldlu8r4dldl4u3drr4u6lulddl4drrddrrd4r4uruuldrdlldl4u3drr4u6luldl5drrddrrdrru3lrd4r3ull3u2(3l3d)rr3uruuldrdllr3dll7u4d3r3urr4du3r3dllu3lrr5ull3d3l3drr3uruuldrdllr3dll6u3drrdd3ruu4lr3dll5udd8rddlldluud3ruu7lr3dll4ud8r3u4ruru8lrddlluuru3lrr3dr5drruuruldl4u3drr4u5luld10rdrrdldluuru11l10rd4r3dllrr3u3l5drddl6uruldluru8lrddlluurulld10r7d3luurdld3rdrruldl6uruldluru10l