ldllulrurruurrdd3rldru3luu3ldr3drrddrruuruu3luuluruullddrr3d3rddldd3lduruulullruulururrddlruulldlluullddrrurluldldrddllddrrudrddrrulrurrdlrdrruuludl3dllu4lddrulurrlu3drurrddrruulrurur3drruulluurd3ululrurruullddulrurdrdl4drruulrdd3l4drruldluudl3rulu
