4urruull5d3u8rurrd8luull5d6ruudd6l5urrdd6rll3d7lddrulu4rdrrur3u5lruull5drdl4u8rurrd8l6rddlruu6luull5d3rdrruruuddldllu3l5urrdd6rurrdluldrrdd3l3ruu8luull5d3rdrruruuddldllu3l5urrdd6rurr5dluru3l3r3ulld6luull5d3rdrruru4r3ulld7lruull4duu8rurr3d4lud4r3ulld7l5r3dldllulldldllurur4ud8rurrd9l5r3dldllulldldllurur3u6rd2(drru)u9l5r3dldllulldluu3dllurdruu3rdrru4l
