rrddllr3drdd3ldll3(uru)rd3lur3dlu3d3rdrruluullrrddlludldllur3ururrdulldrll3drruululdr3uld3ruldlddlduruulddrrddrdrrulu3(ul)lddrurrdrruldllddrdru3ldllu3r3ulldduurrdrrulluurruullddrddldrlddldllur5urrllddrrdrurrdlull3dlrrdrruluuru3l3drdr3urul3d3ldllur5urrdd4urrddlruullddll5d3rdrrul3ulr3d3ldllu4rdr3urul
