luuru3rddldr3ulld4l4d5rur4ulldllddrduluuru3r4dldlluuluuruuld3ruuruul3duu4lulld5r4l4drrddrddlldllur7u3drrddrddrrur4u3lrruuruul3duu4lulld5r4l4drrddrddlldl8u3d3ruuldrdlddlrrddrrur4ullrrddld3luururruuruul3duu4lulld5r4l4drrddrdd3l7u3drrdd4r3u3lrruuruul3duu4lulld5r4l4drrddlrrdd3l7u3drru3d4r3u3lrruuruul3duu4lulld5r4l8d5ruru5lrrdd3l7u5d6r3ullruuruul3duu4lulld5r4l6d5ru3rdluluuluuruul3duu5l6d5rdr3u
