textures = {
	["cooldown-1"] = {
		image = "caveexpress-ui-small",
		x0 = 0.8828125,
		y0 = 0.2177734375,
		x1 = 0.060546875,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 31,
		trimmedheight = 32,
		untrimmedwidth = 32,
		untrimmedheight = 32,
	},
	["cooldown-2"] = {
		image = "caveexpress-ui-small",
		x0 = 0.689453125,
		y0 = 0.1572265625,
		x1 = 0.056640625,
		y1 = 0.0302734375,
		trimmedoffsetx = 2,
		trimmedoffsety = 1,
		trimmedwidth = 29,
		trimmedheight = 31,
		untrimmedwidth = 32,
		untrimmedheight = 32,
	},
	["icon-campaign-ice"] = {
		image = "caveexpress-ui-small",
		x0 = 0.744140625,
		y0 = 0.43359375,
		x1 = 0.125,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 1,
		trimmedwidth = 64,
		trimmedheight = 63,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-campaign-rock"] = {
		image = "caveexpress-ui-small",
		x0 = 0.869140625,
		y0 = 0.43359375,
		x1 = 0.125,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 1,
		trimmedwidth = 64,
		trimmedheight = 63,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-campaign"] = {
		image = "caveexpress-ui-small",
		x0 = 0.76171875,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-checkbox-off"] = {
		image = "caveexpress-ui-small",
		x0 = 0.88671875,
		y0 = 0.1240234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 32,
		trimmedheight = 32,
		untrimmedwidth = 32,
		untrimmedheight = 32,
	},
	["icon-checkbox-on"] = {
		image = "caveexpress-ui-small",
		x0 = 0.88671875,
		y0 = 0.1552734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 32,
		trimmedheight = 32,
		untrimmedwidth = 32,
		untrimmedheight = 32,
	},
	["icon-close"] = {
		image = "caveexpress-ui-small",
		x0 = 0.88671875,
		y0 = 0.095703125,
		x1 = 0.06640625,
		y1 = 0.0283203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 34,
		trimmedheight = 29,
		untrimmedwidth = 34,
		untrimmedheight = 29,
	},
	["icon-google-login"] = {
		image = "caveexpress-ui-small",
		x0 = 0.869140625,
		y0 = 0.4951171875,
		x1 = 0.12109375,
		y1 = 0.060546875,
		trimmedoffsetx = 5,
		trimmedoffsety = 5,
		trimmedwidth = 62,
		trimmedheight = 62,
		untrimmedwidth = 72,
		untrimmedheight = 72,
	},
	["icon-heart"] = {
		image = "caveexpress-ui-small",
		x0 = 0.88671875,
		y0 = 0.1865234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 32,
		trimmedheight = 32,
		untrimmedwidth = 32,
		untrimmedheight = 32,
	},
	["icon-plus"] = {
		image = "caveexpress-ui-small",
		x0 = 0.88671875,
		y0 = 0.0283203125,
		x1 = 0.0703125,
		y1 = 0.037109375,
		trimmedoffsetx = 14,
		trimmedoffsety = 13,
		trimmedwidth = 36,
		trimmedheight = 38,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-reload"] = {
		image = "caveexpress-ui-small",
		x0 = 0.744140625,
		y0 = 0.4951171875,
		x1 = 0.125,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 1,
		trimmedwidth = 64,
		trimmedheight = 63,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-result"] = {
		image = "caveexpress-ui-small",
		x0 = 0.88671875,
		y0 = 0,
		x1 = 0.083984375,
		y1 = 0.0283203125,
		trimmedoffsetx = 10,
		trimmedoffsety = 18,
		trimmedwidth = 43,
		trimmedheight = 29,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-scroll-page-DIR"] = {
		image = "caveexpress-ui-small",
		x0 = 0.88671875,
		y0 = 0.0654296875,
		x1 = 0.068359375,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 31,
		untrimmedwidth = 35,
		untrimmedheight = 31,
	},
	["icon-settings"] = {
		image = "caveexpress-ui-small",
		x0 = 0.626953125,
		y0 = 0.1572265625,
		x1 = 0.0625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 1,
		trimmedwidth = 32,
		trimmedheight = 31,
		untrimmedwidth = 32,
		untrimmedheight = 32,
	},
	["icon-star-disabled"] = {
		image = "caveexpress-ui-small",
		x0 = 0.626953125,
		y0 = 0.1875,
		x1 = 0.255859375,
		y1 = 0.123046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 131,
		trimmedheight = 126,
		untrimmedwidth = 131,
		untrimmedheight = 126,
	},
	["icon-star-enabled"] = {
		image = "caveexpress-ui-small",
		x0 = 0.626953125,
		y0 = 0.310546875,
		x1 = 0.255859375,
		y1 = 0.123046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 131,
		trimmedheight = 126,
		untrimmedwidth = 131,
		untrimmedheight = 126,
	},
	["map-icon-locked"] = {
		image = "caveexpress-ui-small",
		x0 = 0.76171875,
		y0 = 0.0625,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-0"] = {
		image = "caveexpress-ui-small",
		x0 = 0.76171875,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-1"] = {
		image = "caveexpress-ui-small",
		x0 = 0.244140625,
		y0 = 0.3857421875,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-2"] = {
		image = "caveexpress-ui-small",
		x0 = 0.369140625,
		y0 = 0.3857421875,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-3"] = {
		image = "caveexpress-ui-small",
		x0 = 0.494140625,
		y0 = 0.3857421875,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked"] = {
		image = "caveexpress-ui-small",
		x0 = 0.619140625,
		y0 = 0.43359375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["mouse"] = {
		image = "caveexpress-ui-small",
		x0 = 0.94921875,
		y0 = 0.1240234375,
		x1 = 0.048828125,
		y1 = 0.0341796875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 35,
		untrimmedwidth = 25,
		untrimmedheight = 35,
	},
	["ui-background-gameover"] = {
		image = "caveexpress-ui-small",
		x0 = 0,
		y0 = 0.1572265625,
		x1 = 0.626953125,
		y1 = 0.228515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 321,
		trimmedheight = 234,
		untrimmedwidth = 321,
		untrimmedheight = 234,
	},
	["ui-background-title"] = {
		image = "caveexpress-ui-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.76171875,
		y1 = 0.1572265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 390,
		trimmedheight = 161,
		untrimmedwidth = 390,
		untrimmedheight = 161,
	},
	["ui-button-start"] = {
		image = "caveexpress-ui-small",
		x0 = 0,
		y0 = 0.3857421875,
		x1 = 0.244140625,
		y1 = 0.119140625,
		trimmedoffsetx = 2,
		trimmedoffsety = 2,
		trimmedwidth = 125,
		trimmedheight = 122,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
}
