5dld2(drulur)rluurr6drd3lrr5ulldll3d10ldllu10r4(drulur)rluurr6drdllr5ulldll3d10l3ulldrdrddllu10r4(drulur)rluurr6drdl5ulldll3d11l6uluur4dr3dld9r4(drulur)rluurr6d4ulldll3d10luullur5urr3dr3(ul)7d7u6r3dldl3dld6r4(drulur)rluurr5drdllr4ulldll3d10ldllu10r4(drulur)rluurr5d3ulldll3d7l3uldduurruuru3ldlu4ruu3ldllul7drd8r3(drulur)drulu3rur5dl4ulldll3d10ldllu10r4(drulur)rluurr5d3ulldll3d7l3ur3ulldlurullul7drddllu10r4(drulur)rluurr4duulldll3d7l4u3rdrru3l4uldrd3ldlurullul7drddllu10r3(drulur)drulu3rur4dl3ulldll3d7l3uruud5r4ull3d3urr4d4luu3ldlurullul7drddllu10r4(drulur)rluurr4duulldll3d7l3uruud5ruulruull3durrdd4luu3ldlurullul7drddllu10r4(drulur)rluurr3dulldll3d7l3uruuru3ldlurullul4dr3dld9r3(drulur)drulu3rur3duu3ldll3d10luullurur3dld9r3(drulur)drulu3rurdd
