d5r4urrdll5rddluru3ldrluul2(lddr)ul3urrdlul3drd7l5u3l5drdr5u4dll5urrur4dldrd6r4ulldrur3drd7l5u3l5drdr5u4dll5urrur3dldrdd6r3ulldrurddrd7l5u3l5drdr5u4dll5urrur3dl3d7ruruluurrdlul3drd7lul4ull5drdr5u4dll5urr5d7r3u3rdllulddrd7luluurdl3ull5drdru7r3u5rd4lulddrd8luuruulull5drdruruuluuddrddl3u3d3rulldluud3rullu
