ru4r4ldllu5rddluru3l5dllurdrdurr3uruu3l5d4ulld3luurdldlrdd4rd3r3uruu3l4d3ulld3l3r5urrdlu3l4dl3d5r3ull3u4druruldd3l5urruluu2(lldd)rrll2(uurr)ddr4d5ruu4lr3ullddrd4r4dlu4dl3d2(rruu)llrr2(ddll)3ul3udd5lu3l2(ddrr)uudd2(lluu)3rd3r3drrll3u3luuruu3ldduu3rddlud4ruu3r4l4udll4d3u3l2(uurr)dr3d5rd3r2(uull)dduu2(rrdd)3lu4l4rdd5luuddrdd3l4r3drr4ud3ruudd3ldd3r2(ddll)u3l3ur4luulrr5urruuldrdd5r3dl4d3lu3l3d2(lluu)rrlu7rdduuluu3r4luu5rddrluul3u2(rrdd)llrd3l5dlldurru3r2(ddll)ulru
