llulldr4drd4ruu3ludrdu3ruruuldlldurruullddu3lulld4r3l4drdrdrruruurudlddlluuluuddrddrruulrruruuldlldldlurrurruulld3lulldr4drdrd2(rruruul)ulld3luld4rurrdrddldllulludrrdrruruululld3lulld3rddrrdrddldllulul3u3drdrdrruruululldrurudlluululldr4drdrdrruluulur3drruulrddlluul3ululldr4drdrdrullulld3rdrruruu3l3ulul4d3urr3d3rddldllu3lurdrrdr2(ruruu)ldlldldlurrurruulld3lulldr5drrdrruruururuluulld3l3rurr4dlddldllull5u4rurr4dllulludrrdrddldllull5urr3drl3ull5drrdrruluul3ull5drrdrruruululrdrddldlluruulud3rddldluudrruull3r4ull3dlr3urrddlruullddrrddldd5l5u3r3l5d5ruur4ulld5lur
