rdrr3u3(ru)rrurrdrrurrdldl3drdl4uruul5dl5dldrurdl4urrul5ullulld4rurrdlul4dl6dldr4urruul4u6l3(dl)lururu8rurrdlul5drdl5u8ldlddrurudlluru8rurrdlul5dldr5u8lddrulu8rurrdlul5drruululduu6ld3l5dllurdr3u2(lurdru)lu8rurrdlulddu6ld3l7dluulurdr3u2(lurdru)lu8rurrdluld6ld3l4d4ld3rdr4u2(lurdru)luru3r3lddll6drrdlddll3udluurdr4ulurdrulurl5d3lurrdr3ulur5drrulddl5u3(ru)dldllurl4dll4dru3dl4urdr5uruuldrdldd3ldrrdr4uruuldruurrdlulddr3urd6rurrd8l2(uldrdl)uu9rddrdd3luururu7luldrdluldu8rddlddr3uru7luldrdllu8r4drruulrddll3uru7lulddu7rddl4dr5uru7luldrdlu7r3d3ldrr5drr3dll7ur4uru7luld7r3dlldr5drrddldl7ur4uru8l7r3dlldr5drrdldl6ur4uru7l6r3dlldrddrrul4uru6lrulld6rddrrddldl4uru6l3ru3l
