5u4r5dr2(l3urd)l7drul3drul9ulldrl9drr9ulu3ldrl9drr9ulu3ldrl9drr9ulu3ldrl9drr9urr11d6lul6urruruuldr3uld3r9dll9u7dlur3dlud5rdd6rur6ullrr6dld6luu4r7urdl6d4ldd6rur6ullrr6dld6luu4r5uruullrrddl5dll7u3rddllr5dll5urrddlr3dll3urrddldlurr4uruul6drdl3urul3dlldlldd6rur6ullul3duu3r6dld6luurru3r3u3d3ldlldd6rur6ulluldr4d3ldll9u5r3dldrddldr3uldr5u5l11d6rur6ulld2(lur3d)lulldrurr6u4l4r6dlld3l7u5rdd4l4r4dlld3l5u5rdd4l4rddlld3l3u3drruldlud4l7uldr6d4rdd6lul6urrur5dld6ru4r6u6l6r6d4ld3l7u7rdd6l6r4d4ld3l5u7rdd6l6rdd4ld3l3u3drruldludll3ulur4d4rdd6lul6urrur5dld4ru6r6u8l8r6d6ld3l7u9rdd8l8ruu10l3dru9rdd8l8rdd6ld3l3u3drrul8ruu9lddldrrl3uluur4dl3uru9ruu9l4duu11r6ulu12ldl6drrurd9r4u10lddrddlddrdl3urd3uldrd11r6ulu12ldl6drrdrul3dru9rdd5ldu3ldru7ruu10l3drurrdlu3rdlu4l4ull6dr2(d6ru)ruu4rd8rur4ulluld3ull6d3rud3l6u3rdu3l6drr3u3dllurdrull3d4rur4u4l4r4ulu4l5d3urrdluld3u4rdr4d3luu4drud3l3d4rur4ullrr4ulu4l3drr3drdl4urdu3l3u4rdr4dlldlu3r4dld4l3url3d4rur4ull3dlulldrurruu3l3dllurdrull5urruu4ldl4drrdrddlu6r4ullu4ldr4dldrrullur4urruu4ldl4drrll4uru4rddll4d3ulduu3ruu4ldl4drrdrul3dru3rdllulluull4dr2(d4ru)r4u7l5rdd6luuruulurrl3d5ruu3ludlullddrulurrd4r4d5l3ud7r4ulu8ldl4drrurdl3urd3rulldllddll4uru4rd
