l5u3r3d5rululu5lul6drd3ldlu3r6u3r3d3rulldluudrrulu3lul6drdllullddrurr6u4rddluru3lul6drd4lurrdr3uluruu3rdd4rulu5lul6drdllr6u3rddrruru5lul6drdlu3lddrulu3rdlullddru4rull5u6rururuuldlddrd6lul3dldr3u8ruululddrd6lul6drd3ldlu3r6u7r4urrdlul3drd7lul6drd3lrr6u3rdd4rudruu7lul6drdllr6u8ruuluurrdlul3drd7lul6drdl
