function getName()
	return "Map 14"
end

function onMapLoaded()
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-rock-ice-03", 0, 0)
	map:addTile("tile-ground-ledge-ice-right-01", 0, 1)
	map:addTile("tile-background-ice-02", 0, 2)
	map:addTile("tile-background-ice-01", 0, 3)
	map:addTile("tile-background-ice-02", 0, 4)
	map:addTile("tile-background-ice-07", 0, 5)
	map:addTile("tile-ground-ice-05", 0, 6)
	map:addTile("tile-background-ice-04", 0, 7)
	map:addTile("tile-background-ice-06", 0, 8)
	map:addTile("tile-background-ice-06", 0, 9)
	map:addTile("tile-background-ice-07", 0, 10)
	map:addTile("tile-background-ice-02", 0, 11)
	map:addTile("tile-rock-ice-02", 1, 0)
	map:addTile("tile-ground-ledge-ice-right-02", 1, 1)
	map:addTile("tile-background-ice-07", 1, 2)
	map:addTile("tile-background-ice-02", 1, 3)
	map:addTile("tile-background-ice-05", 1, 4)
	map:addTile("tile-background-ice-window-02", 1, 5)
	map:addTile("tile-ground-ice-01", 1, 6)
	map:addTile("tile-background-ice-04", 1, 7)
	map:addTile("tile-background-ice-07", 1, 8)
	map:addTile("tile-background-ice-04", 1, 9)
	map:addTile("tile-background-ice-04", 1, 10)
	map:addTile("tile-background-ice-02", 1, 11)
	map:addTile("tile-rock-ice-03", 2, 0)
	map:addTile("tile-rock-shim-ice-01", 2, 1)
	map:addTile("tile-background-ice-04", 2, 2)
	map:addTile("tile-background-ice-02", 2, 3)
	map:addTile("tile-background-ice-03", 2, 4)
	map:addTile("tile-ground-ice-05", 2, 6)
	map:addTile("tile-background-ice-04", 2, 7)
	map:addTile("tile-background-ice-02", 2, 8)
	map:addTile("tile-background-ice-big-01", 2, 9)
	map:addTile("tile-background-ice-02", 2, 11)
	map:addTile("tile-rock-slope-ice-right-02", 3, 0)
	map:addTile("tile-background-ice-03", 3, 1)
	map:addTile("tile-background-ice-05", 3, 2)
	map:addTile("tile-background-ice-02", 3, 3)
	map:addTile("tile-background-ice-04", 3, 4)
	map:addTile("tile-background-ice-cave-art-01", 3, 5)
	map:addTile("tile-ground-ice-04", 3, 6)
	map:addTile("tile-background-ice-06", 3, 7)
	map:addTile("tile-background-ice-02", 3, 8)
	map:addTile("tile-background-ice-02", 3, 11)
	map:addTile("tile-background-ice-05", 4, 0)
	map:addTile("tile-background-ice-05", 4, 1)
	map:addTile("tile-background-ice-06", 4, 2)
	map:addTile("tile-background-ice-02", 4, 3)
	map:addTile("tile-background-ice-02", 4, 4)
	map:addTile("tile-background-ice-big-01", 4, 5)
	map:addTile("tile-background-ice-01", 4, 7)
	map:addTile("tile-background-ice-06", 4, 8)
	map:addTile("tile-background-ice-06", 4, 9)
	map:addTile("tile-background-ice-big-01", 4, 10)
	map:addTile("tile-background-ice-04", 5, 0)
	map:addTile("tile-background-ice-01", 5, 1)
	map:addTile("tile-background-ice-03", 5, 2)
	map:addTile("tile-background-ice-05", 5, 3)
	map:addTile("tile-background-ice-04", 5, 4)
	map:addTile("tile-background-ice-03", 5, 7)
	map:addTile("tile-background-ice-02", 5, 8)
	map:addTile("tile-background-ice-05", 5, 9)
	map:addTile("tile-background-ice-04", 6, 0)
	map:addTile("tile-background-ice-05", 6, 1)
	map:addTile("tile-background-ice-04", 6, 2)
	map:addTile("tile-background-ice-04", 6, 3)
	map:addTile("tile-background-ice-02", 6, 4)
	map:addTile("tile-background-ice-06", 6, 5)
	map:addTile("tile-background-ice-03", 6, 6)
	map:addTile("tile-background-ice-02", 6, 7)
	map:addTile("tile-background-ice-big-01", 6, 8)
	map:addTile("tile-background-ice-05", 6, 10)
	map:addTile("tile-background-ice-02", 6, 11)
	map:addTile("tile-background-ice-03", 7, 0)
	map:addTile("tile-background-ice-04", 7, 1)
	map:addTile("tile-background-ice-04", 7, 2)
	map:addTile("tile-background-ice-02", 7, 3)
	map:addTile("tile-background-ice-03", 7, 4)
	map:addTile("tile-background-ice-06", 7, 5)
	map:addTile("tile-background-ice-01", 7, 6)
	map:addTile("tile-background-ice-05", 7, 7)
	map:addTile("tile-rock-slope-ice-left-01", 7, 10)
	map:addTile("tile-rock-ice-01", 7, 11)
	map:addTile("tile-background-ice-04", 8, 0)
	map:addTile("tile-background-ice-04", 8, 1)
	map:addTile("tile-background-ice-06", 8, 2)
	map:addTile("tile-background-ice-04", 8, 3)
	map:addTile("tile-background-ice-05", 8, 4)
	map:addTile("tile-background-ice-02", 8, 5)
	map:addTile("tile-background-ice-01", 8, 6)
	map:addTile("tile-background-ice-05", 8, 7)
	map:addTile("tile-background-ice-05", 8, 8)
	map:addTile("tile-background-ice-06", 8, 9)
	map:addTile("tile-packagetarget-ice-01-idle", 8, 10)
	map:addTile("tile-rock-ice-03", 8, 11)
	map:addTile("tile-background-ice-06", 9, 0)
	map:addTile("tile-background-ice-04", 9, 1)
	map:addTile("tile-background-ice-06", 9, 2)
	map:addTile("tile-background-ice-04", 9, 3)
	map:addTile("tile-background-ice-01", 9, 4)
	map:addTile("tile-ground-ledge-ice-left-01", 9, 5)
	map:addTile("tile-background-ice-07", 9, 6)
	map:addTile("tile-background-ice-07", 9, 7)
	map:addTile("tile-background-ice-01", 9, 8)
	map:addTile("tile-geyser-ice-01-idle", 9, 9)
	map:addTile("tile-rock-ice-01", 9, 11)
	map:addTile("tile-background-ice-06", 10, 0)
	map:addTile("tile-background-ice-07", 10, 1)
	map:addTile("tile-background-ice-04", 10, 2)
	map:addTile("tile-background-ice-04", 10, 3)
	map:addTile("tile-background-ice-window-01", 10, 4)
	map:addTile("tile-ground-ice-01", 10, 5)
	map:addTile("tile-rock-ice-big-01", 10, 6)
	map:addTile("tile-rock-ice-03", 10, 8)
	map:addTile("tile-rock-ice-02", 10, 9)
	map:addTile("tile-rock-ice-01", 10, 10)
	map:addTile("tile-rock-ice-03", 10, 11)
	map:addTile("tile-background-ice-05", 11, 0)
	map:addTile("tile-background-ice-04", 11, 1)
	map:addTile("tile-background-ice-04", 11, 2)
	map:addTile("tile-background-ice-04", 11, 3)
	map:addTile("tile-ground-ice-03", 11, 5)
	map:addTile("tile-rock-ice-02", 11, 8)
	map:addTile("tile-rock-ice-01", 11, 9)
	map:addTile("tile-rock-ice-03", 11, 10)
	map:addTile("tile-rock-ice-01", 11, 11)
	map:addTile("tile-background-ice-04", 12, 0)
	map:addTile("tile-background-ice-06", 12, 1)
	map:addTile("tile-background-ice-04", 12, 2)
	map:addTile("tile-background-ice-05", 12, 3)
	map:addTile("tile-background-ice-02", 12, 4)
	map:addTile("tile-ground-ledge-ice-right-01", 12, 5)
	map:addTile("tile-background-ice-07", 12, 6)
	map:addTile("tile-background-ice-05", 12, 7)
	map:addTile("tile-background-ice-02", 12, 8)
	map:addTile("tile-ground-ice-02", 12, 9)
	map:addTile("tile-rock-ice-01", 12, 10)
	map:addTile("tile-rock-ice-03", 12, 11)
	map:addTile("tile-background-ice-03", 13, 0)
	map:addTile("tile-background-ice-04", 13, 1)
	map:addTile("tile-background-ice-06", 13, 2)
	map:addTile("tile-background-ice-02", 13, 3)
	map:addTile("tile-background-ice-05", 13, 4)
	map:addTile("tile-background-ice-06", 13, 5)
	map:addTile("tile-background-ice-04", 13, 6)
	map:addTile("tile-background-ice-04", 13, 7)
	map:addTile("tile-background-ice-05", 13, 8)
	map:addTile("tile-ground-ice-05", 13, 9)
	map:addTile("tile-background-ice-01", 13, 10)
	map:addTile("tile-background-ice-05", 13, 11)
	map:addTile("tile-background-ice-06", 14, 0)
	map:addTile("tile-background-ice-07", 14, 1)
	map:addTile("tile-background-ice-03", 14, 2)
	map:addTile("tile-background-ice-03", 14, 3)
	map:addTile("tile-background-ice-04", 14, 4)
	map:addTile("tile-background-ice-04", 14, 5)
	map:addTile("tile-background-ice-05", 14, 6)
	map:addTile("tile-background-ice-06", 14, 7)
	map:addTile("tile-background-ice-03", 14, 8)
	map:addTile("tile-ground-ice-02", 14, 9)
	map:addTile("tile-background-ice-07", 14, 10)
	map:addTile("tile-background-ice-02", 14, 11)
	map:addTile("tile-background-ice-06", 15, 0)
	map:addTile("tile-background-ice-04", 15, 1)
	map:addTile("tile-background-ice-02", 15, 2)
	map:addTile("tile-background-ice-07", 15, 3)
	map:addTile("tile-background-ice-05", 15, 4)
	map:addTile("tile-background-ice-06", 15, 5)
	map:addTile("tile-background-ice-02", 15, 6)
	map:addTile("tile-background-ice-04", 15, 7)
	map:addTile("tile-background-ice-03", 15, 8)
	map:addTile("tile-ground-ledge-ice-right-01", 15, 9)
	map:addTile("tile-background-ice-05", 15, 10)
	map:addTile("tile-background-ice-02", 15, 11)

	map:addCave("tile-cave-ice-01", 2, 5, "none", 5000)
	map:addCave("tile-cave-ice-01", 11, 4, "none", 5000)

	map:addEmitter("tree", 13, 7, 1, 0, "")
	map:addEmitter("tree", 13, 7, 1, 0, "")
	map:addEmitter("item-stone", 15, 8, 1, 0, "")

	map:setSetting("fishnpc", "true")
	map:setSetting("flyingnpc", "true")
	map:setSetting("gravity", "9.81")
	map:setSetting("height", "12")
	map:setSetting("packagetransfercount", "3")
	map:addStartPosition("9", "4")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "30")
	map:setSetting("theme", "ice")
	map:setSetting("waterheight", "1")
	map:setSetting("waterchangespeed", "0")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("width", "16")
	map:setSetting("wind", "0.0")
end
