rd6rdd10ruuldrd9ldl3uruuldrd6lu3lddrru6rdd6rurrdrruuldrd9ldl3uruuldrd6lulluldldd3ru6rdd4r3ulurrdrruruullddrdllul3drd4ldl3uruuldrd6lullull3d3ru6rdd3ru5rdrruuldrd9ldl3uruuldrd6luulldrurdu4l3d3ru6r5luulldrurdld5r4luu4ld3rurdld4r4ldllulu3rurdld3r
