textures = {
	["npc-grandpa-falling-middle-01"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0.8046875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-falling-middle-02"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0.7041015625,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-falling-middle-03"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0.603515625,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-falling-middle-04"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.765625,
		y0 = 0.5029296875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-falling-middle-05"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.57421875,
		y0 = 0.5029296875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-falling-middle-06"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.3828125,
		y0 = 0.5029296875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-falling-middle-07"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0.5029296875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-idle-middle-01"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0.8046875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-idle-middle-02"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0.7041015625,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-idle-middle-03"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0.603515625,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-idle-middle-04"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0.5029296875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-idle-middle-01"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.765625,
		y0 = 0.40234375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-idle-middle-02"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.57421875,
		y0 = 0.40234375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-idle-middle-03"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.3828125,
		y0 = 0.40234375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-idle-middle-04"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0.40234375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-left-middle-01"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0.40234375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-left-middle-02"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.765625,
		y0 = 0.3017578125,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-left-middle-03"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.57421875,
		y0 = 0.3017578125,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-right-middle-01"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.3828125,
		y0 = 0.3017578125,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-right-middle-02"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0.3017578125,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-swimming-right-middle-03"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0.3017578125,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-left-middle-01"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.765625,
		y0 = 0.201171875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-left-middle-02"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.57421875,
		y0 = 0.201171875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-left-middle-03"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.3828125,
		y0 = 0.201171875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-left-middle-04"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0.201171875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-left-middle-05"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0.201171875,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-left-middle-06"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.765625,
		y0 = 0.1005859375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-left-middle-06_nm"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.57421875,
		y0 = 0.1005859375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-left-middle-07"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.3828125,
		y0 = 0.1005859375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-right-middle-01"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0.1005859375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-right-middle-02"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0.1005859375,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-right-middle-03"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.765625,
		y0 = 0,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-right-middle-04"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.57421875,
		y0 = 0,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-right-middle-05"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.3828125,
		y0 = 0,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-right-middle-06"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0.19140625,
		y0 = 0,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
	["npc-grandpa-walk-right-middle-07"] = {
		image = "caveexpress-npc_grandpa-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.19140625,
		y1 = 0.1005859375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 98,
		trimmedheight = 103,
		untrimmedwidth = 98,
		untrimmedheight = 103,
	},
}
