2(u3ld)dl4drdrdrr4u3l3r4dllulul3udlur3drdrd4rurr5uluu6l3dl3drdrdrr4u3luldr4u3rdllul3d3u5rdrr6dlldll4u3lulld3l3rurrd3r4dllululldldll4d4ur3(rd)d4r4luururu4rurr6u5l5r3dluuru3l3r5dl4urulu6l4d5rll4drrur4ud6lulld7rll4drrurr4ulddrddlld4luluuddrd4rurr6ulu6l3dld6rll4drruldluuddllurdrullddldldd4r3u3d4luururu3r3ldldl4drdd5rurr6u3lu3ldldldd4r3urullr4d4luururrlldldd4r3u3ldl4drdd3r5u5drruldl4u4dllurdr3udd4r3ulddrd3ldluud4r5ul4drd3ldlu3luulurrlluurdldruullulull4d3r3l4ur3(rd)drddlludrruuld3ululull4d3rdruruulldurrddluluulull4d3r3ulu4ldll3d5r5lddrulu4r4luurdld3rll4d3rulldl3ulurrl4d5ru4ldl3ulur3urrurdduurrdluldrruururruu5l3d3u5rd2(dlldl)luurlddrrul3rururruu5l3dldrdrruulrddllururrurruu5l3d4l5uruu3r5d5ulldrur4d4urrdlul3duu4l3druulu3rurddu4l5dr4ulu3rurd3rddrdll3rddlludrruullrdrdd7r3u7l3d6ruuru5l5r3ulddrd4l3r4ulldrur3drd3lrr4u4ld3rur3drdllr4u6ld5rur3drdl
