uu3ldlldrur3drluurdl3urdurrd3lddrulurl4drudrrulrddurrdlurruuldrdrdlrddl3ulldrurrddlul3uruul4d3ldrlddruldlrddlurddrruldldludllu3ruuldrddlluru3rdrru4l3uldulldrluudllurdllddrululurluur3drruldlluurdr3dlddr4u3rulr4uruuldduu3rdlld3lulld4r3duld
