3r3l3urrddrdlu3rdlrddluruu3lddrrululuull4drruldl4u3(ruldlu)urulddrr3d3rddrdrrulldlldl4u3(ruldlu)rr3d3rddrd4ru4ldlldl4uruldluruldl3uldrr3d3rddrdlldlulldllu4r3u2(ruldlu)rullrr3d3r3dldlu4luurdld4r3u3(ruldlu)udrr3d3r3dldl4u3(ruldlu)rr3d3rdd7rd5lddrulu3ldl4u2(ruldlu)ur3d3rdd4rd5ldl4u2(ruldlu)rulr3d3rdd5rddlldluru4ldl4u2(ruldlu)rr6d3rurrddluru4ldl4uruldluudd3rdd4ruurruull4drd6ldl4uruldlurullrdd3rdd4ruurrulul4drd6ldl4uruldluruldd3rdd4ruull3urur6drd6ldl4uruldlud3rdd4ruulluululuurdld3rur6drd6ldl5udrrdd4r6ulldlluurdld3rur6drd6ldl4urulld3rdd4ruulluurur5drd6ldl4uruldrrdd4ruullurur4drd6ldl4u
