rdlddrurr4d3rur7u4lddrulu3rur4dldrl4d3l4ulldrur3duu3l3ururrdruluu7l3d3ru4ru3rur6dl4d4lur3u3l3ururrdrulu3rur3duu3ld3ld4lddrur3l4ull7d4ru3rurr4drrdr3uruulur3dluu4d3l4ulldrur3d3u3luluu4rdrulu3rur5dldrl4d4lu3rdr4u3d3l3u5lddrrudlluu4rur3duu3l3ulu4rdrulu3rur7dldrldd4lu3rdr3udd3l3u3luuldulldrd4rur3d3ulluulu3rdlrrulu3rur7dl3d4lurrl3ulluulldld4rur3d3u3(lu)3rdrulu3rdr5dl3dllurdruudd4lu3rdru3l3ul3ulurrdrulurrurr6d6ulldrur5d5u11ldd7rdrulu3rur4d3u3ldlldd4lulu6rdrulu3rur3d
