uur3(ru)u4rllururldd3l3dlld4lululuulluuddluludrrddldlruu3r3drrdrr4dl3(ld)d4lrrdldlrurduurr3urru4rdrdrddrrdduurdrdulluururldd3l3ullull4urrurr3u3lruuddrr3dllddldlddlluurrdld3rullruurd3urr3ull4d4lull3urruuddll3drrd4r6uruul4drrddlldd4lull3urruu3r3lddll3drrd4rurr3ulluuddlurullrdd3rdd3l3u3drdd4lull3urrdrrllull3drrd4ruulud3ruur3(rd)dlluu4d4l4r4uruu3lddllddldd3r4u4d4lddrrdrr4u3drulurdr3uddll6d3ruururr3u4lrrdllrdluu4r3dlldldd3l3ullu4ldll3dl3(lu)urr4d6u8r6l4d4u5ruu3lull4d7u3lddldll3drrdduurrllururldd3l3urrdd2(rdlr)3dl4dr6ul2(luuruu)3r6dllrr6u3lddlddrdd7rddrrdrr3u8l4rddlludrruuruu3lull3d6rluulldr3dllurdruudllull3urrdrddldr3ulduull3drrurd3l6u3l2(ddlddr)r4d5rl6u8dlddr8u8d4rururuullddllululdd4urdr3drr3ulr3dlluurrdldlull5u4r3dl3d2(3ruu)rurr3u4luurruuluu5luuruu3r3drd3lrr4u3lddrrluurrddr4drddldduurdd4uluur4duulldduuruulddll3r4u5ldd4r4luu5rddrdlu5lulld6r4luu5rdduuluu4l3du5rdd5l6rdd4ldlluluuruu6rurrd3ldd5luu4r4ldd3rud3rdd3lud3ruuldrddrr3ullrrddldluddldd3r3dlldldd3lddllu4lu4l4ul2(luuruu)3r3drrd4ruuluulur3drdd4lull3urrurlddrrllull3drrd4ruululldrullullddrr4uluur4dll2(ddrr)uuddllull3u3l2(ddlddr)r4d4rd3ruulrddlu6ldlu5rd4ruddrruu4l7ruururr3u4l5drd3lrr6uruul6drdd3lddllu4lu4l4ul2(luuruu)3rddrrdd4rurrurr4d4ulldllurrlldd4lull3u3l2(ddlddr)r4d4rdrrd4ruu3ruururr3ulluuruuldrdlddrr3dlldlluuruulurdruuruulddrrdd3lddlddr3(ru)ddlldl2(dd3l)4u3r5urldrrll4d3l4d2(3ruu)luurrddl2(dd3l)4u3ruurrludrddrruullrrdrrulldd4l3rdd5l5ruururr3d6l6ruulldurrddllddrddl4udllulld3rluludl4drruudd2(lluu)rrlld4l5u4rddl3dld3rdru3l4urdd3urrdlulduu4lddrrdduull3drrdru3ldldd3r3u3drrurulrrdd4l3ulldlddrrlluur4urrdduulldru3rurru4l4rdd6ldd4l4ul2(luuruu)3rddrrdd4rurr5d5ulld3ldd4r4luu3rurr3d3lud3r3ulldllrrurrdllrrdd8l6u3l2(ddlddr)r4d2(4ruu)rruuddlddruu3ludrdd4luurrludrdullddrrllulldrrull7u6drrll6urr4u4dll4drr4ullddrurdll4drr6dlddr4u4d4luu3rdru5luurrduluurrldl3ulluuruuruulldll3urrurd3lddrrddrddlddll4u4d4rddlluurr4dll3ulurdd4rurrd4lddlluurrlldr3dldllurruruuld3ull3drrlluururdll6u3rddldduurrddululuull4drruud3rll3urdrllddrullddldd3ruudd3luurdldr3ur3uldduullddrruuluul3d3urrddll4urrdd4uluur4drruuldlu4ruulldurrddlldd4ruullrrdd8l4d4r6udd4lddrrdldr3udlluurrurrddlrurrdluruu4drddl4urruullddlluurrlldllurr3luu2(rddr)ruulldd4ruullddllurd3ruulldurrddlluuruu3l2(dduurr)dd
