textures = {
	["bones"] = {
		image = "cavepacker-ui-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.478515625,
		y1 = 0.0791015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 490,
		trimmedheight = 81,
		untrimmedwidth = 490,
		untrimmedheight = 81,
	},
	["icon-close"] = {
		image = "cavepacker-ui-big",
		x0 = 0.125,
		y0 = 0.5849609375,
		x1 = 0.0654296875,
		y1 = 0.0556640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 67,
		trimmedheight = 57,
		untrimmedwidth = 67,
		untrimmedheight = 57,
	},
	["icon-cursor-down"] = {
		image = "cavepacker-ui-big",
		x0 = 0.25,
		y0 = 0.0791015625,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 200,
		untrimmedwidth = 200,
		untrimmedheight = 200,
	},
	["icon-cursor-left"] = {
		image = "cavepacker-ui-big",
		x0 = 0.4453125,
		y0 = 0.24609375,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 200,
		untrimmedwidth = 200,
		untrimmedheight = 200,
	},
	["icon-cursor-right"] = {
		image = "cavepacker-ui-big",
		x0 = 0.25,
		y0 = 0.2744140625,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 200,
		untrimmedwidth = 200,
		untrimmedheight = 200,
	},
	["icon-cursor-up"] = {
		image = "cavepacker-ui-big",
		x0 = 0,
		y0 = 0.3291015625,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 200,
		untrimmedwidth = 200,
		untrimmedheight = 200,
	},
	["icon-google-login"] = {
		image = "cavepacker-ui-big",
		x0 = 0.8359375,
		y0 = 0.24609375,
		x1 = 0.140625,
		y1 = 0.140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 144,
		trimmedheight = 144,
		untrimmedwidth = 144,
		untrimmedheight = 144,
	},
	["icon-reload"] = {
		image = "cavepacker-ui-big",
		x0 = 0.8359375,
		y0 = 0.38671875,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["icon-scroll-page-DIR"] = {
		image = "cavepacker-ui-big",
		x0 = 0.125,
		y0 = 0.5244140625,
		x1 = 0.068359375,
		y1 = 0.060546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 62,
		untrimmedwidth = 70,
		untrimmedheight = 62,
	},
	["icon-settings"] = {
		image = "cavepacker-ui-big",
		x0 = 0.8203125,
		y0 = 0.51171875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-star-disabled"] = {
		image = "cavepacker-ui-big",
		x0 = 0.478515625,
		y0 = 0,
		x1 = 0.255859375,
		y1 = 0.24609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 262,
		trimmedheight = 252,
		untrimmedwidth = 262,
		untrimmedheight = 252,
	},
	["icon-star-enabled"] = {
		image = "cavepacker-ui-big",
		x0 = 0.734375,
		y0 = 0,
		x1 = 0.255859375,
		y1 = 0.24609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 262,
		trimmedheight = 252,
		untrimmedwidth = 262,
		untrimmedheight = 252,
	},
	["icon-undo"] = {
		image = "cavepacker-ui-big",
		x0 = 0.640625,
		y0 = 0.24609375,
		x1 = 0.1953125,
		y1 = 0.1953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 200,
		untrimmedwidth = 200,
		untrimmedheight = 200,
	},
	["map-icon-locked"] = {
		image = "cavepacker-ui-big",
		x0 = 0.4453125,
		y0 = 0.44140625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked-0"] = {
		image = "cavepacker-ui-big",
		x0 = 0.1953125,
		y0 = 0.4697265625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked-1"] = {
		image = "cavepacker-ui-big",
		x0 = 0.3203125,
		y0 = 0.4697265625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked-2"] = {
		image = "cavepacker-ui-big",
		x0 = 0,
		y0 = 0.5244140625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked-3"] = {
		image = "cavepacker-ui-big",
		x0 = 0.5703125,
		y0 = 0.44140625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked"] = {
		image = "cavepacker-ui-big",
		x0 = 0.6953125,
		y0 = 0.44140625,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["mouse"] = {
		image = "cavepacker-ui-big",
		x0 = 0.1953125,
		y0 = 0.3291015625,
		x1 = 0.0478515625,
		y1 = 0.0673828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 49,
		trimmedheight = 69,
		untrimmedwidth = 49,
		untrimmedheight = 69,
	},
	["ui-button-start"] = {
		image = "cavepacker-ui-big",
		x0 = 0,
		y0 = 0.0791015625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
}
