rddrdldlluurrddlddluurruulddr4ulddrddllddrr4uddlldllurrddrrullrr3ullddrluurrddlddluulldrrurruulldurrddlluurd3rulldll3drruuddll3urrllddllurdrdrrullrruulldurdruurrdlldlluurr4dlluurruuluur4dluuddlddruu3ldrrurruulldurrddllddrrudlluurdl3urd3rulldllddrrudlluurrurrdllddll3urrdluldrr3ulddrdrruldlulldrrddlludrud3lurrdrr3ulldduurr3dll3uruurddll3drruldlulldrurruurdulldu4rdluluuld
