3ulddrd3rulldluluu3ruurrdluldrdlurr3urr2(dlrrddlu)r2(uull)ddrllddrudrdrlu3lddlluu3rlddrr3drrddluruldlurdd3rdd2(luddllur)d2(rruu)llduulldrldldur3uluulldrldrlddruullur3dllddllurdrulurdll3dll2(urlluurd)l2(ddrr)uulrruuldululrd3ruruuldulldr3(ru)ullddrdd3l3ulluurdldrurdluu3luu2(rduurrdl)u2(lldd)rruddrrulrurudl3drddl3u3d3ruuruuldrdrr3dulurulddldd3lrurdru
