urruurlddru5rdruruurrdrrddl3dld9l9rurrd10l10rddluru9l8rddluru7lulddrd3luluurddru9r4uruul5drd9lullrd9r4ur4ul7drd10l9r7u3ldrrur6drd9ldlluurd9r6u3ld10l3u4rdduu4l3drrurd5ru4rur6drd11l10r6u3lddlu9l3u4rddld5ru4rur6drd10l9r6u3lddlulu4rur6drd9ldlurul
