urrdduulldru3ldr5d18r5u3ldd4luu3lulldrdd3ldllu4rdrruluu3rurrdldd4ruu3r5d18l6urrdlu3rdldd3rdrruluu3rurddu4ldd3ldllu4rdruud4l3ulldrurdduu4ldrrl5d18r5u3ldd3ldllu4rdruud4luu3lulld4rurddu4ldd3ldllu4rdruud4l3ulldrurddu3l5d18r6u4ld4r3ldd3ldllu4rdruud4luu3lulld4rurddu4ldd3ldllu4rdruud4luu3l5d18r6u4ldrrldd3ldllu4rdruud4luu3lulld4rurddu4ldd4luu3l5d18r6ulldru3ldrdd3ldllu4rdruu
