ldlrrllulldrruruuldrdldlddr4udrrdluldllurrururrdrdd3lulldrurrdrruulullulddu3rdrddllulldlddr4udrrdluld4ruululldlddldd4rud4luuruururrdrddlruulullulddu3rdrddldd4luurruulur3dludllurrl3d4ruu3luld4rdd3lud3ruu3luuruul4dru3ldrrurrdrdd3luuruuluurdlddrdl3urdl4d3ruuruululrdrddldd3luurrlluurdl3urdd
