#include <miniracer/shared/MiniRacerAchievement.h>

namespace miniracer {

namespace Achievements {
Achievement STARS_3("achievement_3_x_3_stars", true);
Achievement STARS_10("achievement_10_x_3_stars", true);
Achievement STARS_300("achievement_300_x_3_stars", true);
}

}
