#pragma once

#include "common/Animation.h"

namespace caveexpress {

namespace Animations {
extern Animation ANIMATION_WALK_LEFT;
extern Animation ANIMATION_WALK_RIGHT;
extern Animation ANIMATION_IDLE;
extern Animation ANIMATION_FALLING;
extern Animation ANIMATION_SWIMMING_LEFT;
extern Animation ANIMATION_SWIMMING_RIGHT;
extern Animation ANIMATION_SWIMMING_IDLE;
extern Animation ANIMATION_FLYING;
extern Animation ANIMATION_CRASHED;
extern Animation ANIMATION_FLYING_LEFT;
extern Animation ANIMATION_FLYING_RIGHT;
extern Animation ANIMATION_ATTACK_INIT_LEFT;
extern Animation ANIMATION_ATTACK_INIT_RIGHT;
extern Animation ANIMATION_ATTACK_LEFT;
extern Animation ANIMATION_ATTACK_RIGHT;
extern Animation ANIMATION_FALLING_LEFT;
extern Animation ANIMATION_FALLING_RIGHT;
extern Animation ANIMATION_FLYING_FALLING_LEFT;
extern Animation ANIMATION_FLYING_FALLING_RIGHT;
extern Animation ANIMATION_IDLE_LEFT;
extern Animation ANIMATION_IDLE_RIGHT;
extern Animation ANIMATION_TURN_LEFT;
extern Animation ANIMATION_TURN_RIGHT;
extern Animation ANIMATION_KNOCKOUT_LEFT;
extern Animation ANIMATION_KNOCKOUT_RIGHT;
extern Animation ANIMATION_DAZED;
extern Animation ANIMATION_DAZED_LEFT;
extern Animation ANIMATION_DAZED_RIGHT;
extern Animation ANIMATION_WAKEUP_LEFT;
extern Animation ANIMATION_WAKEUP_RIGHT;
extern Animation ANIMATION_ACTIVE;
extern Animation ANIMATION_EXPLODE;
extern Animation ANIMATION_ROTATE;
}

}
