-- create a new campaign
local c = Campaign.new("ice")
-- set an ingame icon for this campaign
c:setSetting("icon", "icon-campaign-ice")
-- set the on screen message when this campaign is activated
c:setSetting("text", "Ice Campaign")
-- now add all maps
c:addMaps("ice-01")
c:addMaps("ice-02")
c:addMaps("ice-03")
c:addMaps("ice-04")
c:addMaps("ice-05")
c:addMaps("ice-06")
c:addMaps("ice-07")
c:addMaps("ice-08")
c:addMaps("ice-09")
c:addMaps("ice-10")
c:addMaps("ice-11")
c:addMaps("ice-12")
c:addMaps("ice-13")
c:addMaps("ice-14")
c:addMaps("ice-15")
c:addMaps("ice-16")
c:addMaps("ice-17")
c:addMaps("ice-18")
c:addMaps("ice-20")
c:addMaps("ice-21")
