ld4ldllrdrddluddll2(urd3l)uruuldu3rdlrddrruulrruruu5ldulldu5rdduu4rdlu3rdlddrud3lddrudrrud12ldd6rdduu5l5d6ruuruuddrruluddlldd5r5ulldl3duldr3ulldllddrrlluulldrduurrdr3u6l5drru3ruuludrruuldrdlu4rurrd5luld6rddlur3dlur3u5lddlddru3l3u5r5l3dldll3urrll3drruruu3luurrdrlull4druluurulluu9r3ur4luulldr2(urrd)u3rurrd6rdd3ldldd8ruululldrurdrrullr3d8l3u3rd4rurd3luluurddldllur3l3drruuddll3ulldrurdurrd3rlull3ruulduldrrdd3lddrudrud6rddld4luldlddlddlluluurr3luurrdr3(dl)urr3ulldrduurd3rlurdrrurrdrddrddllullrrdrruuluurdullulldrdrlu3lddrrulr3dlulu2(udrdrr)u4l
