l3(dld)r3uruul3duul5ulu8rur8drdul7u8l5d3rurrd3lrrddlu3l3ulur4drruruulullr3(rd)ruuldldd3l6u4r3drruldluddldd3l6u8r3d3lddrulur4dl3uruu4lddrdd3luu4rlddrlluru3(ldd)rdrr6ul3u4r5dldlruu4lddlddrdrr5u3l6u8r7dldlluru3l4drruu3drruldluruurr4lrrdd3ldllu4rdru3luudd3luurdrddlulur3ul6u8r8d6l6r8u8l8durdl3ullddrruuld3lurrd2(rr3ulldduu)rrddlulldrurr5dllulldrr4ulldrrluururr8d8ruu6l6r6u8l5rurrluuldllulld4rurdurdrdd8l8d8ruurrurrd4l6u3drrurrdllddrdlrdl
