4u4lddrluu2(ll4u)rrdu4luurrdull4dlluurldd4rddllud4r4d4ruu3lrddlluull3ud4r2(u3dll)3udrr4drruu4r4dll3udrruu5lrddrluu4r4dll3udrr4u5lrdu2(4rdd)5lruu6rdd3lruu4l4drr3udlluu4rddrruurrdd5lruulluu5l3r6drr3ud4ruu4rdd9lrddll3ud10r4urr4d11l5ruu5rluu2(rrddll4u)rr3du4l3udrruu6ldd3rluu6r4d4l3udrr2(uu4l)4d5rluu4r4dll3udrruulluu6lddlldd4ruulrdd3rluulruurrddl3r4dll3ud8luulldd11rlddrr4d4ruu3l3rdd4luulld4ud4rdu4lddrru3d4ruu3l3rddlludrrddllud6luu3rldd5lruu3r
