function getName()
	return "Map 13"
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-background-cave-art-01", 0, 0)
	map:addTile("tile-background-01", 0, 1)
	map:addTile("tile-ground-01", 0, 2)
	map:addTile("tile-rock-03", 0, 3)
	map:addTile("tile-rock-03", 0, 4)
	map:addTile("tile-background-01", 0, 5)
	map:addTile("tile-background-01", 0, 6)
	map:addTile("tile-ground-01", 0, 7)
	map:addTile("tile-rock-01", 0, 8)
	map:addTile("tile-rock-01", 0, 9)
	map:addTile("tile-rock-01", 0, 10)
	map:addTile("tile-rock-01", 0, 11)
	map:addTile("tile-background-02", 1, 0)
	map:addTile("tile-ground-01", 1, 2)
	map:addTile("tile-rock-03", 1, 3)
	map:addTile("tile-rock-slope-right-02", 1, 4)
	map:addTile("tile-background-01", 1, 5)
	map:addTile("tile-background-03", 1, 6)
	map:addTile("tile-packagetarget-rock-01-idle", 1, 7)
	map:addTile("tile-rock-big-01", 1, 8)
	map:addTile("tile-rock-03", 1, 10)
	map:addTile("tile-rock-01", 1, 11)
	map:addTile("tile-background-03", 2, 0)
	map:addTile("tile-background-window-01", 2, 1)
	map:addTile("tile-ground-04", 2, 2)
	map:addTile("tile-rock-slope-right-02", 2, 3)
	map:addTile("tile-background-cave-art-01", 2, 4)
	map:addTile("tile-background-01", 2, 5)
	map:addTile("tile-background-02", 2, 6)
	map:addTile("tile-ground-03", 2, 7)
	map:addTile("tile-rock-03", 2, 10)
	map:addTile("tile-rock-01", 2, 11)
	map:addTile("tile-background-02", 3, 0)
	map:addTile("tile-background-01", 3, 1)
	map:addTile("tile-ground-ledge-right-01", 3, 2)
	map:addTile("tile-background-02", 3, 3)
	map:addTile("tile-background-01", 3, 4)
	map:addTile("tile-background-01", 3, 5)
	map:addTile("tile-background-01", 3, 6)
	map:addTile("tile-background-01", 3, 7)
	map:addTile("tile-ground-01", 3, 8)
	map:addTile("tile-rock-02", 3, 9)
	map:addTile("tile-rock-big-01", 3, 10)
	map:addTile("tile-background-01", 4, 0)
	map:addTile("tile-background-01", 4, 1)
	map:addTile("tile-background-02", 4, 2)
	map:addTile("tile-background-01", 4, 3)
	map:addTile("tile-background-01", 4, 4)
	map:addTile("tile-background-01", 4, 5)
	map:addTile("tile-background-01", 4, 6)
	map:addTile("tile-background-01", 4, 7)
	map:addTile("tile-ground-01", 4, 8)
	map:addTile("tile-ground-02", 4, 9)
	map:addTile("tile-background-01", 5, 0)
	map:addTile("tile-background-02", 5, 1)
	map:addTile("tile-background-02", 5, 2)
	map:addTile("tile-background-big-01", 5, 3)
	map:addTile("tile-background-01", 5, 5)
	map:addTile("tile-background-01", 5, 6)
	map:addTile("tile-background-03", 5, 7)
	map:addTile("tile-ground-03", 5, 8)
	map:addTile("tile-rock-02", 5, 9)
	map:addTile("tile-rock-01", 5, 10)
	map:addTile("tile-rock-01", 5, 11)
	map:addTile("tile-background-03", 6, 0)
	map:addTile("tile-background-01", 6, 1)
	map:addTile("tile-background-01", 6, 2)
	map:addTile("tile-background-01", 6, 5)
	map:addTile("tile-background-01", 6, 6)
	map:addTile("tile-ground-01", 6, 8)
	map:addTile("tile-rock-03", 6, 9)
	map:addTile("tile-rock-02", 6, 10)
	map:addTile("tile-rock-01", 6, 11)
	map:addTile("tile-background-02", 7, 0)
	map:addTile("tile-background-01", 7, 1)
	map:addTile("tile-background-02", 7, 2)
	map:addTile("tile-background-01", 7, 3)
	map:addTile("tile-background-02", 7, 4)
	map:addTile("tile-background-02", 7, 5)
	map:addTile("tile-background-03", 7, 6)
	map:addTile("tile-background-window-01", 7, 7)
	map:addTile("tile-ground-ledge-right-01", 7, 8)
	map:addTile("tile-background-01", 7, 9)
	map:addTile("tile-background-03", 7, 10)
	map:addTile("tile-background-01", 7, 11)
	map:addTile("bridge-wall-left-01", 7, 11)
	map:addTile("tile-background-01", 8, 0)
	map:addTile("tile-background-03", 8, 1)
	map:addTile("tile-background-02", 8, 2)
	map:addTile("tile-background-01", 8, 3)
	map:addTile("tile-background-03", 8, 4)
	map:addTile("tile-background-02", 8, 5)
	map:addTile("tile-background-02", 8, 6)
	map:addTile("tile-background-03", 8, 7)
	map:addTile("tile-ground-05", 8, 8)
	map:addTile("tile-background-01", 8, 9)
	map:addTile("tile-background-02", 8, 10)
	map:addTile("tile-background-01", 8, 11)
	map:addTile("bridge-plank-01", 8, 11)
	map:addTile("tile-background-big-01", 9, 0)
	map:addTile("tile-background-02", 9, 2)
	map:addTile("tile-background-01", 9, 3)
	map:addTile("tile-background-01", 9, 4)
	map:addTile("tile-background-01", 9, 5)
	map:addTile("tile-background-03", 9, 6)
	map:addTile("tile-background-big-01", 9, 7)
	map:addTile("tile-background-01", 9, 9)
	map:addTile("tile-background-01", 9, 10)
	map:addTile("tile-background-01", 9, 11)
	map:addTile("bridge-plank-01", 9, 11)
	map:addTile("tile-background-03", 10, 2)
	map:addTile("tile-background-02", 10, 3)
	map:addTile("tile-background-03", 10, 4)
	map:addTile("tile-ground-06", 10, 5)
	map:addTile("tile-background-01", 10, 6)
	map:addTile("tile-background-01", 10, 9)
	map:addTile("tile-background-01", 10, 10)
	map:addTile("tile-background-cave-art-01", 10, 11)
	map:addTile("bridge-wall-right-01", 10, 11)
	map:addTile("tile-background-01", 11, 0)
	map:addTile("tile-background-01", 11, 1)
	map:addTile("tile-background-01", 11, 2)
	map:addTile("tile-background-03", 11, 3)
	map:addTile("tile-background-03", 11, 4)
	map:addTile("tile-ground-ledge-left-01", 11, 5)
	map:addTile("tile-background-01", 11, 6)
	map:addTile("tile-background-01", 11, 7)
	map:addTile("tile-background-02", 11, 8)
	map:addTile("tile-background-03", 11, 9)
	map:addTile("tile-background-window-02", 11, 10)
	map:addTile("tile-ground-01", 11, 11)
	map:addTile("tile-background-01", 12, 0)
	map:addTile("tile-background-big-01", 12, 1)
	map:addTile("tile-background-01", 12, 3)
	map:addTile("tile-background-01", 12, 4)
	map:addTile("tile-ground-03", 12, 5)
	map:addTile("tile-rock-slope-left-02", 12, 6)
	map:addTile("tile-background-01", 12, 7)
	map:addTile("tile-background-02", 12, 8)
	map:addTile("tile-background-01", 12, 9)
	map:addTile("tile-ground-03", 12, 11)
	map:addTile("tile-background-01", 13, 0)
	map:addTile("tile-background-01", 13, 3)
	map:addTile("tile-ground-03", 13, 5)
	map:addTile("tile-rock-01", 13, 6)
	map:addTile("tile-rock-shim-01", 13, 7)
	map:addTile("tile-background-02", 13, 8)
	map:addTile("tile-background-01", 13, 9)
	map:addTile("tile-background-01", 13, 10)
	map:addTile("tile-ground-01", 13, 11)
	map:addTile("tile-background-big-01", 14, 0)
	map:addTile("tile-background-big-01", 14, 2)
	map:addTile("tile-background-window-02", 14, 4)
	map:addTile("tile-ground-01", 14, 5)
	map:addTile("tile-rock-slope-right-02", 14, 6)
	map:addTile("tile-background-01", 14, 7)
	map:addTile("tile-background-02", 14, 8)
	map:addTile("tile-background-01", 14, 9)
	map:addTile("tile-background-01", 14, 10)
	map:addTile("tile-background-01", 14, 11)
	map:addTile("tile-background-02", 15, 4)
	map:addTile("tile-background-03", 15, 5)
	map:addTile("tile-background-03", 15, 6)
	map:addTile("tile-background-03", 15, 7)
	map:addTile("tile-background-02", 15, 8)
	map:addTile("tile-background-03", 15, 9)
	map:addTile("tile-background-03", 15, 10)
	map:addTile("tile-background-01", 15, 11)

	map:addCave("tile-cave-01", 1, 1, "none", 5000)
	map:addCave("tile-cave-02", 6, 7, "none", 5000)
	map:addCave("tile-cave-01", 12, 10, "none", 5000)
	map:addCave("tile-cave-01", 13, 4, "none", 5000)

	map:addEmitter("item-stone", 2, 6, 1, 0)
	map:addEmitter("tree", 10, 3, 1, 0)

	map:setSetting("fishnpc", "true")
	map:setSetting("flyingnpc", "true")
	map:setSetting("gravity", "9.81")
	map:setSetting("height", "12")
	map:setSetting("packages", "0")
	map:setSetting("packagetransfercount", "4")
	map:addStartPosition("0", "6")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "10")
	map:setSetting("theme", "rock")
	map:setSetting("waterheight", "0.7")
	map:setSetting("waterchangespeed", "0")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("width", "16")
	map:setSetting("wind", "0")
end
