3lulldrdd4l5u4rlluu3r7u5ld3lrddlulluu5r5ldlld3rulu3r3l3drrlurulurd3ruuldrdlru4rur7d7u11rdrrurrddlddr3dlluuluulrddrddldr3d3ldlluruuluurrdrlulu3(ur)dlldlluluu5l3d3u7rdrrldd2(ll3d)lldd4lulldrdd4l5urruu3r8u6rdu5rdrrul3rddlddru4dll5drdrddlu8lull3urd3l3(uru)uldll3u4ruu6l8d3lddll5d4ruulluudrr3d4l3url3d4ruullu
