6dlludrr6ulldd11ldd12rldd10lud12r5uru3ldd11ldd12rlddrr5urullr6d10ludlluuluu11ruudd11ldd12rlddrr5urullr6d8ludlluu9rlddrr5ur3(ul)ldrdrluurdr5d6ldulldd7r3ludlluu5r12luu11ruurur3duuluulldld3rurdduluuldldrrurd
