rdrlu3luu5rddrddl3uddllullddul3ulululldr3dlddru3r3ulululldr3dldrdd3rdrruluul3ulululdrrd5rurrdl3dllullrrdrr3u4lulld5rurd4lu3lulldr3dlddrd3rdr3uluuddrdd4luluur3urrdrddr3d4luu3rurddul3ulull3dld4r3u4rurrdlddrddlullulld4l4urrd5rurrd6ldd3rdrruuddllu3luuru3lul4dlddrd3rdrruluul3u4rurrdl3dllulldlu3rdrr3u4lu4l3dlddrd3rdr3udd4luluurdrrll4u4rd4r3dllull3d4lulurr
