textures = {
	["npc-blowing-dazed-DIR-middle-01"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-dazed-DIR-middle-02"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.283203125,
		y0 = 0,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-dazed-DIR-middle-03"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.56640625,
		y0 = 0,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-dazed-DIR-middle-04"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0,
		y0 = 0.078125,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-dazed-DIR-middle-05"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.283203125,
		y0 = 0.078125,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-dazed-DIR-middle-06"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.56640625,
		y0 = 0.078125,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-dazed-DIR-middle-07"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0,
		y0 = 0.15625,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-dazed-DIR-middle-08"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.283203125,
		y0 = 0.15625,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-idle-DIR-middle-01"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.56640625,
		y0 = 0.15625,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-idle-DIR-middle-02"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0,
		y0 = 0.234375,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-idle-DIR-middle-03"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.283203125,
		y0 = 0.234375,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-idle-DIR-middle-04"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.56640625,
		y0 = 0.234375,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-knockout-DIR-middle-01"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0,
		y0 = 0.3125,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-knockout-DIR-middle-02"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.283203125,
		y0 = 0.3125,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-knockout-DIR-middle-03"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.56640625,
		y0 = 0.3125,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-wakeup-DIR-middle-01"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0,
		y0 = 0.390625,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-wakeup-DIR-middle-02"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.283203125,
		y0 = 0.390625,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-wakeup-DIR-middle-03"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.56640625,
		y0 = 0.390625,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-wakeup-DIR-middle-04"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0,
		y0 = 0.46875,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-wakeup-DIR-middle-05"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.283203125,
		y0 = 0.46875,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
	["npc-blowing-wakeup-DIR-middle-06"] = {
		image = "caveexpress-npc_blowing-big",
		x0 = 0.56640625,
		y0 = 0.46875,
		x1 = 0.283203125,
		y1 = 0.078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 580,
		trimmedheight = 160,
		untrimmedwidth = 580,
		untrimmedheight = 160,
	},
}
