u5ldu5rddlud3r5drd4l3uluuluurul3drdrruruulul3(rd)lldl3dldrddllurdr5uluuluurrlluurdrddrdrr4drd3lrr5ulldld3lu3l2(uurr)3drdr3dlddru3r5ulluluurdrdulldrdrldlluluurrllullddrluurrurdrrdrdr5drd4luld4r6ululldrdrldlluluurrlldlluurrurdrrdrdr5drd4l3u5dllurdr3uldrddlluru4r6ululu3ldrrdrdrluluurdrdr5drd4lulddldruu4r6ululldrdrldldduur3u3ld4ldd3rdrrllu3l3urd3rdrdrdulul3ulldldrr3ldd3rdrruuluudlluurrurdldrrurdrdr5drd4l3r6ululldrdrluurdr5drd3lrr6ulldrur5drdll
