#include "CaveExpressAchievement.h"

namespace caveexpress {

namespace Achievements {
Achievement DAZE_PTERODACTYLS("achievement_daze_pterodactyls");
Achievement PICK_UP_FRUIT("achievement_pick_up_fruit");
Achievement FINISH_THE_TUTORIAL("achievement_finish_the_tutorial");
Achievement DAZE_A_MASTODON("achievement_daze_a_mastodon");
Achievement DAZE_A_FISH("achievement_daze_a_fish");
Achievement DELIVER_A_PACKAGE("achievement_deliver_a_package");
Achievement DELIVER_10_PACKAGES("achievement_deliver_10_packages", true);
Achievement DELIVER_50_PACKAGES("achievement_deliver_50_packages", true);
Achievement DELIVER_100_PACKAGES("achievement_deliver_100_packages", true);
Achievement DELIVER_150_PACKAGES("achievement_deliver_150_packages", true);
Achievement COLLECT_100_FRUITS("achievement_collect_100_fruits", true);
Achievement COLLECT_10_STONES("achievement_collect_10_stones", true);
Achievement COLLECT_100_STONES("achievement_collect_100_stones", true);
Achievement DAZE_A_SLEEPING("achievement_daze_a_sleeping_npc");
Achievement DAZE_A_WALKING("achievement_daze_a_walking_npc");
}

}
