urrdrl4dldlddruru4rdrruluuruuruu5ldll4dldlddruru4rdru5luldr4ulluurr5dld5r4l5urru5rddlddllulldlrurrdrruuruu5ldll4du4r4l3urru5rddldllrruruu4luu5rururrdld6luld7ruuldrd6l5r3drrddll5ulurd5lulld6rldd5ldll3d4rurrurrlldlld4l3urru5rdu5ldll3d4rurrur4u4ldu4r4dldlld4l3urru3rlluu5rururrdld6lulddu4r4dldlld4l3urrurrluu7ruuldrd6lulddu4r4dldlld4l3urruruu6r3drrddll5uruuldrd6lulddu4r4dldlldll3u3drruldluud4rdlulld3ldldlddrur3udd4rdrruluuru3ldludlldd4rdr3uru3ldr4ldd5ruurulld4l3dllu6rdr3uruld5luulluurr5dld5rdr3uruur4urr4dll
