u3rurrd6rurrd7l6rdlu5lu3lddrrurullul3drd4lullddruluru4rurrd6r3druuru7lu3lddrrurullul3du4ldd4rdruruu4rdrurrddluru6lu3l3drruurullul3duurr3d5l3ruu4ldlddru6ruu7r3ulddrd6lu3l3drruurullulddurrd6r3urrddurrd3luldrd6lu3ld4ldlddru6ruuruld4rd4ruluurrdlluldrd6luu3ldrrurd3ld4ldlddru6ruuruulldrurd3lddrdruudlluurrlld4ldlddru4rdrulurdruudllu4ldld5rdrulurdrullu3ldld4rdrulur
