ldldr3uldrdd3ruul3u3ldllu5r3drdd3luuluudr3dlud4ruullr3u3lddrddld3rd4ruuruuld5lrrddrdrruuru5l3u3lddrddld3rdrrllull3uluu3r3dlrrddrdl3uluurruuldrdlu4ldllu5rdduu3lddrddld4ruullruurruuldrdlu4lddrddld3rlluu3rdd3lul3ulu4rdduu3l5d4ruullruurruuldrdluldduu3l5d4ruul3u3lddrddld3r3l5u3r3dlr3u3lddrddldrrluu6r3dl
