r3duu5r3dld3luruu3drruldlu4rd4ruuddrdd3ldurrdldrdd4luurrlldll2(dllu)ruluu8rlldlldllrruu4l4d4rurrd4l8r4uruu3lur4l3ull3drdrlulldr4urrdl3rurrd4lulldr3lurr3lulld3ldru8l4dlddrddrrlddrurrdrru4l6rluurdrrddllrurullrrululldldulur3ldrrldulldllu3r3l3druulurur3luu4rulruuldlrdrd4rururluldlldurruu4lrrdlrrdrrddllulld3r
