#include <miniracer/shared/MiniRacerSpriteType.h>

namespace miniracer {

namespace SpriteTypes {
SpriteType SOLID("solid");
SpriteType MOVEABLE("moveable");
SpriteType ROAD("road");
SpriteType DECAL("decal");
SpriteType VEHICLE("vehicle");
SpriteType LAND("land");
SpriteType LIGHTS("lights");
SpriteType RACER("racer");
}

}
