u6ruurldd3luu3rdrrdll3r3ulddllur4lddlluu5rdd3luullddlluu4rddlluullddlluu4rddl3d6lddlruu3rdd3lullurll3druurrdl4ruurrdd5lulu4rddrruurrddlluu4rddlluullddlluu3lddruluruuluurddl4u2(rddldd)3ruu3r3uluulldllrrurrddr3d3ldd3luuruuluu3rurrdd7ru3ruuldrdlrd3luurlddrrulrruuldldd4luu5rlddrruudd8luu4rdurrdd4lrrddrddl4urru2(ru3ld)drrddr4dl6uruu9ld3lddrddldd3ruu4rddrrurldlluu4ldd3luu5rddlluu3lddru4lddrulurrurrddllullurrll3dru3ruurrdd5lruulldd4r4uluur4dlr4urru8rdrdluu3rddlruulldrll3dr3dl4u3dlld10luld3rulurdd3luurlddrrulrr7ulldrur5d
