#pragma once

#include "common/MapFailedReason.h"

namespace caveexpress {

namespace MapFailedReasons {
extern MapFailedReason FAILED_NO;
extern MapFailedReason FAILED_WATER_HEIGHT;
extern MapFailedReason FAILED_NPC_FLYING;
extern MapFailedReason FAILED_NPC_WALKING;
extern MapFailedReason FAILED_NPC_MAMMUT;
extern MapFailedReason FAILED_NPC_FISH;
extern MapFailedReason FAILED_HITPOINTS;
extern MapFailedReason FAILED_NO_MORE_PLAYERS;
extern MapFailedReason FAILED_ALL_NPCS_DIED;
extern MapFailedReason FAILED_SIDESCROLL;
extern MapFailedReason FAILED_MAX;
}

}
