ulul3duu3rur3duulldduurullrddrlluu4rurrdd3lulluluu2(lldd)4rdrulurrlu3rddrruu5ldd5l2(uurr)3d3u2(lldd)4rdruddluu4luu3rluurr3du4lddrru3drrurrdrr4ulluu2(rrdd)lludrruu5l3r4dllulld4lddrru3drruurrddrr7u5drruulrddll3u5dlluurlddrruu4lddlluu4rdd2(rruu)4lulldduurrd4r2(ddll)uu3lr3urrdl5r2(ddll)3u3drruul3ruulld
