ull3ull4dl3drdd4rd3rurr4ur3uluu3ldllduruu3ldlldlldrururrurruuldrdluurr3d4rdr4dl4dld4lu4lul4uruulluu3rllddrulur4dldlldrluurr3drdd3ruu3lddrddrululuu3rddlddll3uddrruldlu4rd3rurr4ur3uluu3l4d3lullrr4dll3u3drrdrddrddrudlluu3rurr3ull3drrurruldldllu3l3ruurrdrrdd3lrruuldrdl4ururrulrddll3uluuluuldurrdd3ldd3r3ldl4du3r3u3dlddll3u3lrddll2(uurr)drdldrrluurl3udrrdd4l3urlddlluurr
