3drrurrddld7lrr5u6l7d3r3ud8rurrd9lrr5ull3dll3ull7d3r3ud9r3ulddrd8lrr5u4l3drl3ull7d3r4udd8ruu3ldu3rdd7lrr5ullddlruu4l7d3r4ulur3d5ruurru3rddrd10lrr5u4ldull3drl4d3r4udd8r5urr4drd10lrr5u6l7d3r3ud5r3urluurdldd3ruullul4du3rdd7lrr5u6l7d3ruu5r4urrdlul3duu3ruur4dld8l8rurrd9l7ruullulddu3rdd6l
