l3u3lrdduurr3d5ldldrl3ulurrldd4r6urrdlul5duurr3d5lulddldruu6r3d3lruuddrr3u5ldluud4r6dllurdr5uddrr3u5lulddu4r6drruldl5uddrr3ull10rddlldlluu5dllullrrdrr3urrurruu6l3drl3u2(ll3d)rrurrdrr5uddrrurruu6l3urrdduull3d5rurulr3drdllruu4l6dllurdr5uddll3u5rdruuruldd4l6ulldrur5duull3d5rdruud4l6urrdlul3drldduull3d5rurddu4l6drruldl5uddll3urrddlr3d5ldl2(3urr)ll3u3r3l6dllurdrudrrud3rl5ululdu4l3ulldrur4drurdll3u4rurr6d6ulldrur4d
