3drul3dr4drr3uruuldllullddrluuruulddrrdrr3drddlull3uluuddr3drr3uruuldllulluurrdduuluurddllddruuddrdrr3drddlull3uluuddr3drr3uruuldllulluurr4dludlulldrrurr3ulldduurr3dll4r3drddlull3u3drr3uruuldll3ull4drl4urruuldr4drr3drddl4urul4dll3u4lur
